"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """User information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_SOURCE_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_HOSTNAME_FIELD_NUMBER: builtins.int
    REGISTRATION_STATE_FIELD_NUMBER: builtins.int
    credentials_source: builtins.str
    """source used to get credentials for the user (dbt_cloud.yml, web)"""
    dbt_cloud_user_id: builtins.str
    """dbt cloud user id, can be null if the user is not registered"""
    dbt_cloud_hostname: builtins.str
    """dbt cloud hostname, can be null if the user is not registered"""
    registration_state: builtins.str
    """registration state as reported by the vscode extension"""
    def __init__(
        self,
        *,
        credentials_source: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
        dbt_cloud_hostname: builtins.str = ...,
        registration_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["credentials_source", b"credentials_source", "dbt_cloud_hostname", b"dbt_cloud_hostname", "dbt_cloud_user_id", b"dbt_cloud_user_id", "registration_state", b"registration_state"]) -> None: ...

global___User = User

@typing.final
class Editor(google.protobuf.message.Message):
    """Editor and extension information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    MACHINE_ID_FIELD_NUMBER: builtins.int
    MAC_MACHINE_ID_FIELD_NUMBER: builtins.int
    EXTENSION_VERSION_FIELD_NUMBER: builtins.int
    EDITOR_NAME_FIELD_NUMBER: builtins.int
    EDITOR_VERSION_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """session id (reported by the editor)"""
    machine_id: builtins.str
    """machine id (reported by the editor)"""
    mac_machine_id: builtins.str
    """hashed mac address (reported by the editor)"""
    extension_version: builtins.str
    """version of the dbt extension"""
    editor_name: builtins.str
    """editor name (reported by the editor)"""
    editor_version: builtins.str
    """editor version (reported by the editor)"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        machine_id: builtins.str = ...,
        mac_machine_id: builtins.str = ...,
        extension_version: builtins.str = ...,
        editor_name: builtins.str = ...,
        editor_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["editor_name", b"editor_name", "editor_version", b"editor_version", "extension_version", b"extension_version", "mac_machine_id", b"mac_machine_id", "machine_id", b"machine_id", "session_id", b"session_id"]) -> None: ...

global___Editor = Editor
