# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vscode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.fields import vscode_types_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_fields_dot_vscode__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vscode.proto\x12\x15v1.public.events.vsce\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a\x31\x64\x62tlabs/proto/public/v1/fields/vscode_types.proto\"\xcb\x02\n\x12\x45xtensionActivated\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x0f\n\x07os_name\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0cinit_success\x18\x06 \x01(\x08\x12\x12\n\ninit_error\x18\x07 \x01(\t\x12\x19\n\x11init_error_detail\x18\x08 \x01(\t\x12\x18\n\x10init_duration_ms\x18\t \x01(\x03:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xa2\x02\n\x13\x45xtensionLspCompile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x05 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x62t_version\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x38Z6github.com/dbt-labs/proto-golang/v1/public/events/vsceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vscode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dbt-labs/proto-golang/v1/public/events/vsce'
  _globals['_EXTENSIONACTIVATED']._loaded_options = None
  _globals['_EXTENSIONACTIVATED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLSPCOMPILE']._loaded_options = None
  _globals['_EXTENSIONLSPCOMPILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONACTIVATED']._serialized_start=220
  _globals['_EXTENSIONACTIVATED']._serialized_end=551
  _globals['_EXTENSIONLSPCOMPILE']._serialized_start=554
  _globals['_EXTENSIONLSPCOMPILE']._serialized_end=844
# @@protoc_insertion_point(module_scope)
