"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CoreEventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

global___CoreEventInfo = CoreEventInfo

@typing.final
class NodeRelation(google.protobuf.message.Message):
    """NodeRelation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    RELATION_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    alias: builtins.str
    relation_name: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        alias: builtins.str = ...,
        relation_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "database", b"database", "relation_name", b"relation_name", "schema", b"schema"]) -> None: ...

global___NodeRelation = NodeRelation

@typing.final
class NodeInfo(google.protobuf.message.Message):
    """NodeInfo"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_PATH_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    MATERIALIZED_FIELD_NUMBER: builtins.int
    NODE_STATUS_FIELD_NUMBER: builtins.int
    NODE_STARTED_AT_FIELD_NUMBER: builtins.int
    NODE_FINISHED_AT_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    NODE_RELATION_FIELD_NUMBER: builtins.int
    NODE_CHECKSUM_FIELD_NUMBER: builtins.int
    node_path: builtins.str
    node_name: builtins.str
    unique_id: builtins.str
    resource_type: builtins.str
    materialized: builtins.str
    node_status: builtins.str
    node_started_at: builtins.str
    node_finished_at: builtins.str
    node_checksum: builtins.str
    @property
    def meta(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def node_relation(self) -> global___NodeRelation: ...
    def __init__(
        self,
        *,
        node_path: builtins.str = ...,
        node_name: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        materialized: builtins.str = ...,
        node_status: builtins.str = ...,
        node_started_at: builtins.str = ...,
        node_finished_at: builtins.str = ...,
        meta: google.protobuf.struct_pb2.Struct | None = ...,
        node_relation: global___NodeRelation | None = ...,
        node_checksum: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta", "node_relation", b"node_relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized", "meta", b"meta", "node_checksum", b"node_checksum", "node_finished_at", b"node_finished_at", "node_name", b"node_name", "node_path", b"node_path", "node_relation", b"node_relation", "node_started_at", b"node_started_at", "node_status", b"node_status", "resource_type", b"resource_type", "unique_id", b"unique_id"]) -> None: ...

global___NodeInfo = NodeInfo

@typing.final
class TimingInfoMsg(google.protobuf.message.Message):
    """TimingInfoMsg"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completed_at", b"completed_at", "name", b"name", "started_at", b"started_at"]) -> None: ...

global___TimingInfoMsg = TimingInfoMsg

@typing.final
class RunResultMsg(google.protobuf.message.Message):
    """RunResult"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TIMING_INFO_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    ADAPTER_RESPONSE_FIELD_NUMBER: builtins.int
    NUM_FAILURES_FIELD_NUMBER: builtins.int
    status: builtins.str
    message: builtins.str
    thread: builtins.str
    execution_time: builtins.float
    num_failures: builtins.int
    @property
    def timing_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimingInfoMsg]: ...
    @property
    def adapter_response(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        message: builtins.str = ...,
        timing_info: collections.abc.Iterable[global___TimingInfoMsg] | None = ...,
        thread: builtins.str = ...,
        execution_time: builtins.float = ...,
        adapter_response: google.protobuf.struct_pb2.Struct | None = ...,
        num_failures: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adapter_response", b"adapter_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_response", b"adapter_response", "execution_time", b"execution_time", "message", b"message", "num_failures", b"num_failures", "status", b"status", "thread", b"thread", "timing_info", b"timing_info"]) -> None: ...

global___RunResultMsg = RunResultMsg

@typing.final
class ColumnType(google.protobuf.message.Message):
    """ColumnType"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    PREVIOUS_COLUMN_TYPE_FIELD_NUMBER: builtins.int
    CURRENT_COLUMN_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    previous_column_type: builtins.str
    current_column_type: builtins.str
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        previous_column_type: builtins.str = ...,
        current_column_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["column_name", b"column_name", "current_column_type", b"current_column_type", "previous_column_type", b"previous_column_type"]) -> None: ...

global___ColumnType = ColumnType

@typing.final
class ColumnConstraint(google.protobuf.message.Message):
    """ColumnConstraint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    constraint_name: builtins.str
    constraint_type: builtins.str
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        constraint_name: builtins.str = ...,
        constraint_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["column_name", b"column_name", "constraint_name", b"constraint_name", "constraint_type", b"constraint_type"]) -> None: ...

global___ColumnConstraint = ColumnConstraint

@typing.final
class ModelConstraint(google.protobuf.message.Message):
    """ModelConstraint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_TYPE_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    constraint_name: builtins.str
    constraint_type: builtins.str
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        constraint_name: builtins.str = ...,
        constraint_type: builtins.str = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "constraint_name", b"constraint_name", "constraint_type", b"constraint_type"]) -> None: ...

global___ModelConstraint = ModelConstraint

@typing.final
class MainReportVersion(google.protobuf.message.Message):
    """A - Pre-project loading

    A001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LOG_VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    log_version: builtins.int
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        log_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_version", b"log_version", "version", b"version"]) -> None: ...

global___MainReportVersion = MainReportVersion

@typing.final
class MainReportVersionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainReportVersion: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainReportVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainReportVersionMsg = MainReportVersionMsg

@typing.final
class MainReportArgs(google.protobuf.message.Message):
    """A002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ArgsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["args", b"args"]) -> None: ...

global___MainReportArgs = MainReportArgs

@typing.final
class MainReportArgsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainReportArgs: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainReportArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainReportArgsMsg = MainReportArgsMsg

@typing.final
class MainTrackingUserState(google.protobuf.message.Message):
    """A003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_STATE_FIELD_NUMBER: builtins.int
    user_state: builtins.str
    def __init__(
        self,
        *,
        user_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_state", b"user_state"]) -> None: ...

global___MainTrackingUserState = MainTrackingUserState

@typing.final
class MainTrackingUserStateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainTrackingUserState: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainTrackingUserState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainTrackingUserStateMsg = MainTrackingUserStateMsg

@typing.final
class MergedFromState(google.protobuf.message.Message):
    """A004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MERGED_FIELD_NUMBER: builtins.int
    SAMPLE_FIELD_NUMBER: builtins.int
    num_merged: builtins.int
    @property
    def sample(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        num_merged: builtins.int = ...,
        sample: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_merged", b"num_merged", "sample", b"sample"]) -> None: ...

global___MergedFromState = MergedFromState

@typing.final
class MergedFromStateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MergedFromState: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MergedFromState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MergedFromStateMsg = MergedFromStateMsg

@typing.final
class MissingProfileTarget(google.protobuf.message.Message):
    """A005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILE_NAME_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    profile_name: builtins.str
    target_name: builtins.str
    def __init__(
        self,
        *,
        profile_name: builtins.str = ...,
        target_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["profile_name", b"profile_name", "target_name", b"target_name"]) -> None: ...

global___MissingProfileTarget = MissingProfileTarget

@typing.final
class MissingProfileTargetMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MissingProfileTarget: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MissingProfileTarget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MissingProfileTargetMsg = MissingProfileTargetMsg

@typing.final
class InvalidOptionYAML(google.protobuf.message.Message):
    """Skipped A006, A007

    A008
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTION_NAME_FIELD_NUMBER: builtins.int
    option_name: builtins.str
    def __init__(
        self,
        *,
        option_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["option_name", b"option_name"]) -> None: ...

global___InvalidOptionYAML = InvalidOptionYAML

@typing.final
class InvalidOptionYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidOptionYAML: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidOptionYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidOptionYAMLMsg = InvalidOptionYAMLMsg

@typing.final
class LogDbtProjectError(google.protobuf.message.Message):
    """A009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

global___LogDbtProjectError = LogDbtProjectError

@typing.final
class LogDbtProjectErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogDbtProjectError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogDbtProjectError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogDbtProjectErrorMsg = LogDbtProjectErrorMsg

@typing.final
class LogDbtProfileError(google.protobuf.message.Message):
    """Skipped A010

    A011
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    PROFILES_FIELD_NUMBER: builtins.int
    exc: builtins.str
    @property
    def profiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
        profiles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "profiles", b"profiles"]) -> None: ...

global___LogDbtProfileError = LogDbtProfileError

@typing.final
class LogDbtProfileErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogDbtProfileError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogDbtProfileError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogDbtProfileErrorMsg = LogDbtProfileErrorMsg

@typing.final
class StarterProjectPath(google.protobuf.message.Message):
    """Skipped A012, A013, A014, A015, A016

    A017
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

global___StarterProjectPath = StarterProjectPath

@typing.final
class StarterProjectPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___StarterProjectPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___StarterProjectPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___StarterProjectPathMsg = StarterProjectPathMsg

@typing.final
class ConfigFolderDirectory(google.protobuf.message.Message):
    """A018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

global___ConfigFolderDirectory = ConfigFolderDirectory

@typing.final
class ConfigFolderDirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfigFolderDirectory: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfigFolderDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfigFolderDirectoryMsg = ConfigFolderDirectoryMsg

@typing.final
class NoSampleProfileFound(google.protobuf.message.Message):
    """A019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTER_FIELD_NUMBER: builtins.int
    adapter: builtins.str
    def __init__(
        self,
        *,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter"]) -> None: ...

global___NoSampleProfileFound = NoSampleProfileFound

@typing.final
class NoSampleProfileFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NoSampleProfileFound: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NoSampleProfileFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NoSampleProfileFoundMsg = NoSampleProfileFoundMsg

@typing.final
class ProfileWrittenWithSample(google.protobuf.message.Message):
    """A020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

global___ProfileWrittenWithSample = ProfileWrittenWithSample

@typing.final
class ProfileWrittenWithSampleMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProfileWrittenWithSample: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProfileWrittenWithSample | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProfileWrittenWithSampleMsg = ProfileWrittenWithSampleMsg

@typing.final
class ProfileWrittenWithTargetTemplateYAML(google.protobuf.message.Message):
    """A021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

global___ProfileWrittenWithTargetTemplateYAML = ProfileWrittenWithTargetTemplateYAML

@typing.final
class ProfileWrittenWithTargetTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProfileWrittenWithTargetTemplateYAML: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProfileWrittenWithTargetTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProfileWrittenWithTargetTemplateYAMLMsg = ProfileWrittenWithTargetTemplateYAMLMsg

@typing.final
class ProfileWrittenWithProjectTemplateYAML(google.protobuf.message.Message):
    """A022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

global___ProfileWrittenWithProjectTemplateYAML = ProfileWrittenWithProjectTemplateYAML

@typing.final
class ProfileWrittenWithProjectTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProfileWrittenWithProjectTemplateYAML: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProfileWrittenWithProjectTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProfileWrittenWithProjectTemplateYAMLMsg = ProfileWrittenWithProjectTemplateYAMLMsg

@typing.final
class SettingUpProfile(google.protobuf.message.Message):
    """A023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SettingUpProfile = SettingUpProfile

@typing.final
class SettingUpProfileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SettingUpProfile: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SettingUpProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SettingUpProfileMsg = SettingUpProfileMsg

@typing.final
class InvalidProfileTemplateYAML(google.protobuf.message.Message):
    """A024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InvalidProfileTemplateYAML = InvalidProfileTemplateYAML

@typing.final
class InvalidProfileTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidProfileTemplateYAML: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidProfileTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidProfileTemplateYAMLMsg = InvalidProfileTemplateYAMLMsg

@typing.final
class ProjectNameAlreadyExists(google.protobuf.message.Message):
    """A025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___ProjectNameAlreadyExists = ProjectNameAlreadyExists

@typing.final
class ProjectNameAlreadyExistsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProjectNameAlreadyExists: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProjectNameAlreadyExists | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProjectNameAlreadyExistsMsg = ProjectNameAlreadyExistsMsg

@typing.final
class ProjectCreated(google.protobuf.message.Message):
    """A026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_NAME_FIELD_NUMBER: builtins.int
    DOCS_URL_FIELD_NUMBER: builtins.int
    SLACK_URL_FIELD_NUMBER: builtins.int
    project_name: builtins.str
    docs_url: builtins.str
    slack_url: builtins.str
    def __init__(
        self,
        *,
        project_name: builtins.str = ...,
        docs_url: builtins.str = ...,
        slack_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["docs_url", b"docs_url", "project_name", b"project_name", "slack_url", b"slack_url"]) -> None: ...

global___ProjectCreated = ProjectCreated

@typing.final
class ProjectCreatedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProjectCreated: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProjectCreated | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProjectCreatedMsg = ProjectCreatedMsg

@typing.final
class PackageRedirectDeprecation(google.protobuf.message.Message):
    """D - Deprecation

    D001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

global___PackageRedirectDeprecation = PackageRedirectDeprecation

@typing.final
class PackageRedirectDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PackageRedirectDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PackageRedirectDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PackageRedirectDeprecationMsg = PackageRedirectDeprecationMsg

@typing.final
class PackageInstallPathDeprecation(google.protobuf.message.Message):
    """D002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PackageInstallPathDeprecation = PackageInstallPathDeprecation

@typing.final
class PackageInstallPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PackageInstallPathDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PackageInstallPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PackageInstallPathDeprecationMsg = PackageInstallPathDeprecationMsg

@typing.final
class ConfigSourcePathDeprecation(google.protobuf.message.Message):
    """D003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

global___ConfigSourcePathDeprecation = ConfigSourcePathDeprecation

@typing.final
class ConfigSourcePathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfigSourcePathDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfigSourcePathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfigSourcePathDeprecationMsg = ConfigSourcePathDeprecationMsg

@typing.final
class ConfigDataPathDeprecation(google.protobuf.message.Message):
    """D004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

global___ConfigDataPathDeprecation = ConfigDataPathDeprecation

@typing.final
class ConfigDataPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfigDataPathDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfigDataPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfigDataPathDeprecationMsg = ConfigDataPathDeprecationMsg

@typing.final
class MetricAttributesRenamed(google.protobuf.message.Message):
    """D006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_NAME_FIELD_NUMBER: builtins.int
    metric_name: builtins.str
    def __init__(
        self,
        *,
        metric_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metric_name", b"metric_name"]) -> None: ...

global___MetricAttributesRenamed = MetricAttributesRenamed

@typing.final
class MetricAttributesRenamedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MetricAttributesRenamed: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MetricAttributesRenamed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MetricAttributesRenamedMsg = MetricAttributesRenamedMsg

@typing.final
class ExposureNameDeprecation(google.protobuf.message.Message):
    """D007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPOSURE_FIELD_NUMBER: builtins.int
    exposure: builtins.str
    def __init__(
        self,
        *,
        exposure: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exposure", b"exposure"]) -> None: ...

global___ExposureNameDeprecation = ExposureNameDeprecation

@typing.final
class ExposureNameDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ExposureNameDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ExposureNameDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ExposureNameDeprecationMsg = ExposureNameDeprecationMsg

@typing.final
class InternalDeprecation(google.protobuf.message.Message):
    """D008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SUGGESTED_ACTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    reason: builtins.str
    suggested_action: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        reason: builtins.str = ...,
        suggested_action: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "reason", b"reason", "suggested_action", b"suggested_action", "version", b"version"]) -> None: ...

global___InternalDeprecation = InternalDeprecation

@typing.final
class InternalDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InternalDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InternalDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InternalDeprecationMsg = InternalDeprecationMsg

@typing.final
class EnvironmentVariableRenamed(google.protobuf.message.Message):
    """D009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

global___EnvironmentVariableRenamed = EnvironmentVariableRenamed

@typing.final
class EnvironmentVariableRenamedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___EnvironmentVariableRenamed: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___EnvironmentVariableRenamed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___EnvironmentVariableRenamedMsg = EnvironmentVariableRenamedMsg

@typing.final
class ConfigLogPathDeprecation(google.protobuf.message.Message):
    """D010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path"]) -> None: ...

global___ConfigLogPathDeprecation = ConfigLogPathDeprecation

@typing.final
class ConfigLogPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfigLogPathDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfigLogPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfigLogPathDeprecationMsg = ConfigLogPathDeprecationMsg

@typing.final
class ConfigTargetPathDeprecation(google.protobuf.message.Message):
    """D011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path"]) -> None: ...

global___ConfigTargetPathDeprecation = ConfigTargetPathDeprecation

@typing.final
class ConfigTargetPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfigTargetPathDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfigTargetPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfigTargetPathDeprecationMsg = ConfigTargetPathDeprecationMsg

@typing.final
class TestsConfigDeprecation(google.protobuf.message.Message):
    """D012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

global___TestsConfigDeprecation = TestsConfigDeprecation

@typing.final
class TestsConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___TestsConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___TestsConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___TestsConfigDeprecationMsg = TestsConfigDeprecationMsg

@typing.final
class ProjectFlagsMovedDeprecation(google.protobuf.message.Message):
    """D013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ProjectFlagsMovedDeprecation = ProjectFlagsMovedDeprecation

@typing.final
class ProjectFlagsMovedDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProjectFlagsMovedDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProjectFlagsMovedDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProjectFlagsMovedDeprecationMsg = ProjectFlagsMovedDeprecationMsg

@typing.final
class SpacesInResourceNameDeprecation(google.protobuf.message.Message):
    """D014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_ID_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    unique_id: builtins.str
    level: builtins.str
    def __init__(
        self,
        *,
        unique_id: builtins.str = ...,
        level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["level", b"level", "unique_id", b"unique_id"]) -> None: ...

global___SpacesInResourceNameDeprecation = SpacesInResourceNameDeprecation

@typing.final
class SpacesInResourceNameDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SpacesInResourceNameDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SpacesInResourceNameDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SpacesInResourceNameDeprecationMsg = SpacesInResourceNameDeprecationMsg

@typing.final
class ResourceNamesWithSpacesDeprecation(google.protobuf.message.Message):
    """D015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_INVALID_NAMES_FIELD_NUMBER: builtins.int
    SHOW_DEBUG_HINT_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    count_invalid_names: builtins.int
    show_debug_hint: builtins.bool
    level: builtins.str
    def __init__(
        self,
        *,
        count_invalid_names: builtins.int = ...,
        show_debug_hint: builtins.bool = ...,
        level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count_invalid_names", b"count_invalid_names", "level", b"level", "show_debug_hint", b"show_debug_hint"]) -> None: ...

global___ResourceNamesWithSpacesDeprecation = ResourceNamesWithSpacesDeprecation

@typing.final
class ResourceNamesWithSpacesDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ResourceNamesWithSpacesDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ResourceNamesWithSpacesDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ResourceNamesWithSpacesDeprecationMsg = ResourceNamesWithSpacesDeprecationMsg

@typing.final
class PackageMaterializationOverrideDeprecation(google.protobuf.message.Message):
    """D016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    MATERIALIZATION_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    materialization_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        materialization_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["materialization_name", b"materialization_name", "package_name", b"package_name"]) -> None: ...

global___PackageMaterializationOverrideDeprecation = PackageMaterializationOverrideDeprecation

@typing.final
class PackageMaterializationOverrideDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PackageMaterializationOverrideDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PackageMaterializationOverrideDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PackageMaterializationOverrideDeprecationMsg = PackageMaterializationOverrideDeprecationMsg

@typing.final
class SourceFreshnessProjectHooksNotRun(google.protobuf.message.Message):
    """D017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SourceFreshnessProjectHooksNotRun = SourceFreshnessProjectHooksNotRun

@typing.final
class SourceFreshnessProjectHooksNotRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SourceFreshnessProjectHooksNotRun: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SourceFreshnessProjectHooksNotRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SourceFreshnessProjectHooksNotRunMsg = SourceFreshnessProjectHooksNotRunMsg

@typing.final
class MFTimespineWithoutYamlConfigurationDeprecation(google.protobuf.message.Message):
    """D018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MFTimespineWithoutYamlConfigurationDeprecation = MFTimespineWithoutYamlConfigurationDeprecation

@typing.final
class MFTimespineWithoutYamlConfigurationDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MFTimespineWithoutYamlConfigurationDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MFTimespineWithoutYamlConfigurationDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MFTimespineWithoutYamlConfigurationDeprecationMsg = MFTimespineWithoutYamlConfigurationDeprecationMsg

@typing.final
class MFCumulativeTypeParamsDeprecation(google.protobuf.message.Message):
    """D019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MFCumulativeTypeParamsDeprecation = MFCumulativeTypeParamsDeprecation

@typing.final
class MFCumulativeTypeParamsDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MFCumulativeTypeParamsDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MFCumulativeTypeParamsDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MFCumulativeTypeParamsDeprecationMsg = MFCumulativeTypeParamsDeprecationMsg

@typing.final
class MicrobatchMacroOutsideOfBatchesDeprecation(google.protobuf.message.Message):
    """D020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MicrobatchMacroOutsideOfBatchesDeprecation = MicrobatchMacroOutsideOfBatchesDeprecation

@typing.final
class MicrobatchMacroOutsideOfBatchesDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MicrobatchMacroOutsideOfBatchesDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MicrobatchMacroOutsideOfBatchesDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MicrobatchMacroOutsideOfBatchesDeprecationMsg = MicrobatchMacroOutsideOfBatchesDeprecationMsg

@typing.final
class GenericJSONSchemaValidationDeprecation(google.protobuf.message.Message):
    """Skipping D021. It belonged to the now deleted PackageRedirectDeprecationSummaryMsg.

    D022
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIOLATION_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    violation: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        violation: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key_path", b"key_path", "violation", b"violation"]) -> None: ...

global___GenericJSONSchemaValidationDeprecation = GenericJSONSchemaValidationDeprecation

@typing.final
class GenericJSONSchemaValidationDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GenericJSONSchemaValidationDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GenericJSONSchemaValidationDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GenericJSONSchemaValidationDeprecationMsg = GenericJSONSchemaValidationDeprecationMsg

@typing.final
class UnexpectedJinjaBlockDeprecation(google.protobuf.message.Message):
    """D023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    msg: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "msg", b"msg"]) -> None: ...

global___UnexpectedJinjaBlockDeprecation = UnexpectedJinjaBlockDeprecation

@typing.final
class UnexpectedJinjaBlockDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnexpectedJinjaBlockDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnexpectedJinjaBlockDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnexpectedJinjaBlockDeprecationMsg = UnexpectedJinjaBlockDeprecationMsg

@typing.final
class DuplicateYAMLKeysDeprecation(google.protobuf.message.Message):
    """D024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DUPLICATE_DESCRIPTION_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    duplicate_description: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        duplicate_description: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duplicate_description", b"duplicate_description", "file", b"file"]) -> None: ...

global___DuplicateYAMLKeysDeprecation = DuplicateYAMLKeysDeprecation

@typing.final
class DuplicateYAMLKeysDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DuplicateYAMLKeysDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DuplicateYAMLKeysDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DuplicateYAMLKeysDeprecationMsg = DuplicateYAMLKeysDeprecationMsg

@typing.final
class CustomTopLevelKeyDeprecation(google.protobuf.message.Message):
    """D025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    msg: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "msg", b"msg"]) -> None: ...

global___CustomTopLevelKeyDeprecation = CustomTopLevelKeyDeprecation

@typing.final
class CustomTopLevelKeyDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CustomTopLevelKeyDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CustomTopLevelKeyDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CustomTopLevelKeyDeprecationMsg = CustomTopLevelKeyDeprecationMsg

@typing.final
class CustomKeyInConfigDeprecation(google.protobuf.message.Message):
    """D026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

global___CustomKeyInConfigDeprecation = CustomKeyInConfigDeprecation

@typing.final
class CustomKeyInConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CustomKeyInConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CustomKeyInConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CustomKeyInConfigDeprecationMsg = CustomKeyInConfigDeprecationMsg

@typing.final
class CustomKeyInObjectDeprecation(google.protobuf.message.Message):
    """D027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

global___CustomKeyInObjectDeprecation = CustomKeyInObjectDeprecation

@typing.final
class CustomKeyInObjectDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CustomKeyInObjectDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CustomKeyInObjectDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CustomKeyInObjectDeprecationMsg = CustomKeyInObjectDeprecationMsg

@typing.final
class DeprecationSummary(google.protobuf.message.Message):
    """D028"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_NAME_FIELD_NUMBER: builtins.int
    EVENT_CODE_FIELD_NUMBER: builtins.int
    OCCURRENCES_FIELD_NUMBER: builtins.int
    event_name: builtins.str
    event_code: builtins.str
    occurrences: builtins.int
    def __init__(
        self,
        *,
        event_name: builtins.str = ...,
        event_code: builtins.str = ...,
        occurrences: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["event_code", b"event_code", "event_name", b"event_name", "occurrences", b"occurrences"]) -> None: ...

global___DeprecationSummary = DeprecationSummary

@typing.final
class DeprecationsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARIES_FIELD_NUMBER: builtins.int
    SHOW_ALL_HINT_FIELD_NUMBER: builtins.int
    show_all_hint: builtins.bool
    @property
    def summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeprecationSummary]: ...
    def __init__(
        self,
        *,
        summaries: collections.abc.Iterable[global___DeprecationSummary] | None = ...,
        show_all_hint: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["show_all_hint", b"show_all_hint", "summaries", b"summaries"]) -> None: ...

global___DeprecationsSummary = DeprecationsSummary

@typing.final
class DeprecationsSummaryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DeprecationsSummary: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DeprecationsSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DeprecationsSummaryMsg = DeprecationsSummaryMsg

@typing.final
class CustomOutputPathInSourceFreshnessDeprecation(google.protobuf.message.Message):
    """D029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___CustomOutputPathInSourceFreshnessDeprecation = CustomOutputPathInSourceFreshnessDeprecation

@typing.final
class CustomOutputPathInSourceFreshnessDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CustomOutputPathInSourceFreshnessDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CustomOutputPathInSourceFreshnessDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CustomOutputPathInSourceFreshnessDeprecationMsg = CustomOutputPathInSourceFreshnessDeprecationMsg

@typing.final
class PropertyMovedToConfigDeprecation(google.protobuf.message.Message):
    """D030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

global___PropertyMovedToConfigDeprecation = PropertyMovedToConfigDeprecation

@typing.final
class PropertyMovedToConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PropertyMovedToConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PropertyMovedToConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PropertyMovedToConfigDeprecationMsg = PropertyMovedToConfigDeprecationMsg

@typing.final
class WEOIncludeExcludeDeprecation(google.protobuf.message.Message):
    """D031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOUND_INCLUDE_FIELD_NUMBER: builtins.int
    FOUND_EXCLUDE_FIELD_NUMBER: builtins.int
    found_include: builtins.bool
    found_exclude: builtins.bool
    def __init__(
        self,
        *,
        found_include: builtins.bool = ...,
        found_exclude: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["found_exclude", b"found_exclude", "found_include", b"found_include"]) -> None: ...

global___WEOIncludeExcludeDeprecation = WEOIncludeExcludeDeprecation

@typing.final
class WEOIncludeExcludeDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___WEOIncludeExcludeDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___WEOIncludeExcludeDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___WEOIncludeExcludeDeprecationMsg = WEOIncludeExcludeDeprecationMsg

@typing.final
class ModelParamUsageDeprecation(google.protobuf.message.Message):
    """D032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ModelParamUsageDeprecation = ModelParamUsageDeprecation

@typing.final
class ModelParamUsageDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ModelParamUsageDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ModelParamUsageDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ModelParamUsageDeprecationMsg = ModelParamUsageDeprecationMsg

@typing.final
class DeprecatedModel(google.protobuf.message.Message):
    """I065"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    model_version: builtins.str
    deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        model_version: builtins.str = ...,
        deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecation_date", b"deprecation_date", "model_name", b"model_name", "model_version", b"model_version"]) -> None: ...

global___DeprecatedModel = DeprecatedModel

@typing.final
class DeprecatedModelMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DeprecatedModel: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DeprecatedModel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DeprecatedModelMsg = DeprecatedModelMsg

@typing.final
class InputFileDiffError(google.protobuf.message.Message):
    """I - Project parsing

    I001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    category: builtins.str
    file_id: builtins.str
    def __init__(
        self,
        *,
        category: builtins.str = ...,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "file_id", b"file_id"]) -> None: ...

global___InputFileDiffError = InputFileDiffError

@typing.final
class InputFileDiffErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InputFileDiffError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InputFileDiffError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InputFileDiffErrorMsg = InputFileDiffErrorMsg

@typing.final
class InvalidValueForField(google.protobuf.message.Message):
    """Skipping I002, I003, I004, I005, I006, I007

    I008
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    field_value: builtins.str
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        field_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field_name", b"field_name", "field_value", b"field_value"]) -> None: ...

global___InvalidValueForField = InvalidValueForField

@typing.final
class InvalidValueForFieldMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidValueForField: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidValueForField | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidValueForFieldMsg = InvalidValueForFieldMsg

@typing.final
class ValidationWarning(google.protobuf.message.Message):
    """I009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    FIELD_NAME_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    field_name: builtins.str
    node_name: builtins.str
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        field_name: builtins.str = ...,
        node_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field_name", b"field_name", "node_name", b"node_name", "resource_type", b"resource_type"]) -> None: ...

global___ValidationWarning = ValidationWarning

@typing.final
class ValidationWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ValidationWarning: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ValidationWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ValidationWarningMsg = ValidationWarningMsg

@typing.final
class ParsePerfInfoPath(google.protobuf.message.Message):
    """I010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___ParsePerfInfoPath = ParsePerfInfoPath

@typing.final
class ParsePerfInfoPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ParsePerfInfoPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ParsePerfInfoPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ParsePerfInfoPathMsg = ParsePerfInfoPathMsg

@typing.final
class PartialParsingErrorProcessingFile(google.protobuf.message.Message):
    """Skipping I013

    I014
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file"]) -> None: ...

global___PartialParsingErrorProcessingFile = PartialParsingErrorProcessingFile

@typing.final
class PartialParsingErrorProcessingFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingErrorProcessingFile: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingErrorProcessingFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingErrorProcessingFileMsg = PartialParsingErrorProcessingFileMsg

@typing.final
class PartialParsingError(google.protobuf.message.Message):
    """I016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExcInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXC_INFO_FIELD_NUMBER: builtins.int
    @property
    def exc_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        exc_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

global___PartialParsingError = PartialParsingError

@typing.final
class PartialParsingErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingErrorMsg = PartialParsingErrorMsg

@typing.final
class PartialParsingSkipParsing(google.protobuf.message.Message):
    """I017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PartialParsingSkipParsing = PartialParsingSkipParsing

@typing.final
class PartialParsingSkipParsingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingSkipParsing: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingSkipParsing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingSkipParsingMsg = PartialParsingSkipParsingMsg

@typing.final
class UnableToPartialParse(google.protobuf.message.Message):
    """Skipped I018, I019, I020, I021, I022, I023

    I024
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    reason: builtins.str
    def __init__(
        self,
        *,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason"]) -> None: ...

global___UnableToPartialParse = UnableToPartialParse

@typing.final
class UnableToPartialParseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnableToPartialParse: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnableToPartialParse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnableToPartialParseMsg = UnableToPartialParseMsg

@typing.final
class StateCheckVarsHash(google.protobuf.message.Message):
    """I025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKSUM_FIELD_NUMBER: builtins.int
    VARS_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    checksum: builtins.str
    vars: builtins.str
    profile: builtins.str
    target: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        checksum: builtins.str = ...,
        vars: builtins.str = ...,
        profile: builtins.str = ...,
        target: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checksum", b"checksum", "profile", b"profile", "target", b"target", "vars", b"vars", "version", b"version"]) -> None: ...

global___StateCheckVarsHash = StateCheckVarsHash

@typing.final
class StateCheckVarsHashMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___StateCheckVarsHash: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___StateCheckVarsHash | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___StateCheckVarsHashMsg = StateCheckVarsHashMsg

@typing.final
class PartialParsingNotEnabled(google.protobuf.message.Message):
    """Skipped I026, I027

    I028
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PartialParsingNotEnabled = PartialParsingNotEnabled

@typing.final
class PartialParsingNotEnabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingNotEnabled: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingNotEnabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingNotEnabledMsg = PartialParsingNotEnabledMsg

@typing.final
class ParsedFileLoadFailed(google.protobuf.message.Message):
    """I029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    exc: builtins.str
    exc_info: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "path", b"path"]) -> None: ...

global___ParsedFileLoadFailed = ParsedFileLoadFailed

@typing.final
class ParsedFileLoadFailedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ParsedFileLoadFailed: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ParsedFileLoadFailed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ParsedFileLoadFailedMsg = ParsedFileLoadFailedMsg

@typing.final
class PartialParsingEnabled(google.protobuf.message.Message):
    """Skipping I030 - I039

    I040
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_FIELD_NUMBER: builtins.int
    ADDED_FIELD_NUMBER: builtins.int
    CHANGED_FIELD_NUMBER: builtins.int
    deleted: builtins.int
    added: builtins.int
    changed: builtins.int
    def __init__(
        self,
        *,
        deleted: builtins.int = ...,
        added: builtins.int = ...,
        changed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added", b"added", "changed", b"changed", "deleted", b"deleted"]) -> None: ...

global___PartialParsingEnabled = PartialParsingEnabled

@typing.final
class PartialParsingEnabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingEnabled: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingEnabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingEnabledMsg = PartialParsingEnabledMsg

@typing.final
class PartialParsingFile(google.protobuf.message.Message):
    """I041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    operation: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
        operation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id", "operation", b"operation"]) -> None: ...

global___PartialParsingFile = PartialParsingFile

@typing.final
class PartialParsingFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___PartialParsingFile: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___PartialParsingFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___PartialParsingFileMsg = PartialParsingFileMsg

@typing.final
class InvalidDisabledTargetInTestNode(google.protobuf.message.Message):
    """Skipped I042, I043, I044, I045, I046, I047, I048, I049

    I050
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_TITLE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    ORIGINAL_FILE_PATH_FIELD_NUMBER: builtins.int
    TARGET_KIND_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    TARGET_PACKAGE_FIELD_NUMBER: builtins.int
    resource_type_title: builtins.str
    unique_id: builtins.str
    original_file_path: builtins.str
    target_kind: builtins.str
    target_name: builtins.str
    target_package: builtins.str
    def __init__(
        self,
        *,
        resource_type_title: builtins.str = ...,
        unique_id: builtins.str = ...,
        original_file_path: builtins.str = ...,
        target_kind: builtins.str = ...,
        target_name: builtins.str = ...,
        target_package: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["original_file_path", b"original_file_path", "resource_type_title", b"resource_type_title", "target_kind", b"target_kind", "target_name", b"target_name", "target_package", b"target_package", "unique_id", b"unique_id"]) -> None: ...

global___InvalidDisabledTargetInTestNode = InvalidDisabledTargetInTestNode

@typing.final
class InvalidDisabledTargetInTestNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidDisabledTargetInTestNode: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidDisabledTargetInTestNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidDisabledTargetInTestNodeMsg = InvalidDisabledTargetInTestNodeMsg

@typing.final
class UnusedResourceConfigPath(google.protobuf.message.Message):
    """I051"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNUSED_CONFIG_PATHS_FIELD_NUMBER: builtins.int
    @property
    def unused_config_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        unused_config_paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["unused_config_paths", b"unused_config_paths"]) -> None: ...

global___UnusedResourceConfigPath = UnusedResourceConfigPath

@typing.final
class UnusedResourceConfigPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnusedResourceConfigPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnusedResourceConfigPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnusedResourceConfigPathMsg = UnusedResourceConfigPathMsg

@typing.final
class SeedIncreased(google.protobuf.message.Message):
    """I052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

global___SeedIncreased = SeedIncreased

@typing.final
class SeedIncreasedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SeedIncreased: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SeedIncreased | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SeedIncreasedMsg = SeedIncreasedMsg

@typing.final
class SeedExceedsLimitSamePath(google.protobuf.message.Message):
    """I053"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

global___SeedExceedsLimitSamePath = SeedExceedsLimitSamePath

@typing.final
class SeedExceedsLimitSamePathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SeedExceedsLimitSamePath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SeedExceedsLimitSamePath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SeedExceedsLimitSamePathMsg = SeedExceedsLimitSamePathMsg

@typing.final
class SeedExceedsLimitAndPathChanged(google.protobuf.message.Message):
    """I054"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

global___SeedExceedsLimitAndPathChanged = SeedExceedsLimitAndPathChanged

@typing.final
class SeedExceedsLimitAndPathChangedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SeedExceedsLimitAndPathChanged: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SeedExceedsLimitAndPathChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SeedExceedsLimitAndPathChangedMsg = SeedExceedsLimitAndPathChangedMsg

@typing.final
class SeedExceedsLimitChecksumChanged(google.protobuf.message.Message):
    """I055"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CHECKSUM_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    checksum_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
        checksum_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checksum_name", b"checksum_name", "name", b"name", "package_name", b"package_name"]) -> None: ...

global___SeedExceedsLimitChecksumChanged = SeedExceedsLimitChecksumChanged

@typing.final
class SeedExceedsLimitChecksumChangedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SeedExceedsLimitChecksumChanged: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SeedExceedsLimitChecksumChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SeedExceedsLimitChecksumChangedMsg = SeedExceedsLimitChecksumChangedMsg

@typing.final
class UnusedTables(google.protobuf.message.Message):
    """I056"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNUSED_TABLES_FIELD_NUMBER: builtins.int
    @property
    def unused_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        unused_tables: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["unused_tables", b"unused_tables"]) -> None: ...

global___UnusedTables = UnusedTables

@typing.final
class UnusedTablesMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnusedTables: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnusedTables | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnusedTablesMsg = UnusedTablesMsg

@typing.final
class WrongResourceSchemaFile(google.protobuf.message.Message):
    """I057"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    PLURAL_RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    YAML_KEY_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    resource_type: builtins.str
    plural_resource_type: builtins.str
    yaml_key: builtins.str
    file_path: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
        resource_type: builtins.str = ...,
        plural_resource_type: builtins.str = ...,
        yaml_key: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "patch_name", b"patch_name", "plural_resource_type", b"plural_resource_type", "resource_type", b"resource_type", "yaml_key", b"yaml_key"]) -> None: ...

global___WrongResourceSchemaFile = WrongResourceSchemaFile

@typing.final
class WrongResourceSchemaFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___WrongResourceSchemaFile: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___WrongResourceSchemaFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___WrongResourceSchemaFileMsg = WrongResourceSchemaFileMsg

@typing.final
class NoNodeForYamlKey(google.protobuf.message.Message):
    """I058"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    YAML_KEY_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    yaml_key: builtins.str
    file_path: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
        yaml_key: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "patch_name", b"patch_name", "yaml_key", b"yaml_key"]) -> None: ...

global___NoNodeForYamlKey = NoNodeForYamlKey

@typing.final
class NoNodeForYamlKeyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NoNodeForYamlKey: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NoNodeForYamlKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NoNodeForYamlKeyMsg = NoNodeForYamlKeyMsg

@typing.final
class MacroNotFoundForPatch(google.protobuf.message.Message):
    """I059"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["patch_name", b"patch_name"]) -> None: ...

global___MacroNotFoundForPatch = MacroNotFoundForPatch

@typing.final
class MacroNotFoundForPatchMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MacroNotFoundForPatch: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MacroNotFoundForPatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MacroNotFoundForPatchMsg = MacroNotFoundForPatchMsg

@typing.final
class NodeNotFoundOrDisabled(google.protobuf.message.Message):
    """I060"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_FILE_PATH_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_TITLE_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    TARGET_KIND_FIELD_NUMBER: builtins.int
    TARGET_PACKAGE_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    original_file_path: builtins.str
    unique_id: builtins.str
    resource_type_title: builtins.str
    target_name: builtins.str
    target_kind: builtins.str
    target_package: builtins.str
    disabled: builtins.str
    def __init__(
        self,
        *,
        original_file_path: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type_title: builtins.str = ...,
        target_name: builtins.str = ...,
        target_kind: builtins.str = ...,
        target_package: builtins.str = ...,
        disabled: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "original_file_path", b"original_file_path", "resource_type_title", b"resource_type_title", "target_kind", b"target_kind", "target_name", b"target_name", "target_package", b"target_package", "unique_id", b"unique_id"]) -> None: ...

global___NodeNotFoundOrDisabled = NodeNotFoundOrDisabled

@typing.final
class NodeNotFoundOrDisabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeNotFoundOrDisabled: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeNotFoundOrDisabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeNotFoundOrDisabledMsg = NodeNotFoundOrDisabledMsg

@typing.final
class JinjaLogWarning(google.protobuf.message.Message):
    """I061"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

global___JinjaLogWarning = JinjaLogWarning

@typing.final
class JinjaLogWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___JinjaLogWarning: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___JinjaLogWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___JinjaLogWarningMsg = JinjaLogWarningMsg

@typing.final
class JinjaLogInfo(google.protobuf.message.Message):
    """I062"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

global___JinjaLogInfo = JinjaLogInfo

@typing.final
class JinjaLogInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___JinjaLogInfo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___JinjaLogInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___JinjaLogInfoMsg = JinjaLogInfoMsg

@typing.final
class JinjaLogDebug(google.protobuf.message.Message):
    """I063"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

global___JinjaLogDebug = JinjaLogDebug

@typing.final
class JinjaLogDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___JinjaLogDebug: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___JinjaLogDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___JinjaLogDebugMsg = JinjaLogDebugMsg

@typing.final
class UnpinnedRefNewVersionAvailable(google.protobuf.message.Message):
    """I064"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    REF_NODE_NAME_FIELD_NUMBER: builtins.int
    REF_NODE_PACKAGE_FIELD_NUMBER: builtins.int
    REF_NODE_VERSION_FIELD_NUMBER: builtins.int
    REF_MAX_VERSION_FIELD_NUMBER: builtins.int
    ref_node_name: builtins.str
    ref_node_package: builtins.str
    ref_node_version: builtins.str
    ref_max_version: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        ref_node_name: builtins.str = ...,
        ref_node_package: builtins.str = ...,
        ref_node_version: builtins.str = ...,
        ref_max_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "ref_max_version", b"ref_max_version", "ref_node_name", b"ref_node_name", "ref_node_package", b"ref_node_package", "ref_node_version", b"ref_node_version"]) -> None: ...

global___UnpinnedRefNewVersionAvailable = UnpinnedRefNewVersionAvailable

@typing.final
class UnpinnedRefNewVersionAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnpinnedRefNewVersionAvailable: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnpinnedRefNewVersionAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnpinnedRefNewVersionAvailableMsg = UnpinnedRefNewVersionAvailableMsg

@typing.final
class UpcomingReferenceDeprecation(google.protobuf.message.Message):
    """I066"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_PACKAGE_FIELD_NUMBER: builtins.int
    REF_MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_LATEST_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    ref_model_package: builtins.str
    ref_model_name: builtins.str
    ref_model_version: builtins.str
    ref_model_latest_version: builtins.str
    ref_model_deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        ref_model_package: builtins.str = ...,
        ref_model_name: builtins.str = ...,
        ref_model_version: builtins.str = ...,
        ref_model_latest_version: builtins.str = ...,
        ref_model_deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name", "ref_model_deprecation_date", b"ref_model_deprecation_date", "ref_model_latest_version", b"ref_model_latest_version", "ref_model_name", b"ref_model_name", "ref_model_package", b"ref_model_package", "ref_model_version", b"ref_model_version"]) -> None: ...

global___UpcomingReferenceDeprecation = UpcomingReferenceDeprecation

@typing.final
class UpcomingReferenceDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UpcomingReferenceDeprecation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UpcomingReferenceDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UpcomingReferenceDeprecationMsg = UpcomingReferenceDeprecationMsg

@typing.final
class DeprecatedReference(google.protobuf.message.Message):
    """I067"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_PACKAGE_FIELD_NUMBER: builtins.int
    REF_MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_LATEST_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    ref_model_package: builtins.str
    ref_model_name: builtins.str
    ref_model_version: builtins.str
    ref_model_latest_version: builtins.str
    ref_model_deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        ref_model_package: builtins.str = ...,
        ref_model_name: builtins.str = ...,
        ref_model_version: builtins.str = ...,
        ref_model_latest_version: builtins.str = ...,
        ref_model_deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name", "ref_model_deprecation_date", b"ref_model_deprecation_date", "ref_model_latest_version", b"ref_model_latest_version", "ref_model_name", b"ref_model_name", "ref_model_package", b"ref_model_package", "ref_model_version", b"ref_model_version"]) -> None: ...

global___DeprecatedReference = DeprecatedReference

@typing.final
class DeprecatedReferenceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DeprecatedReference: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DeprecatedReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DeprecatedReferenceMsg = DeprecatedReferenceMsg

@typing.final
class UnsupportedConstraintMaterialization(google.protobuf.message.Message):
    """I068"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIALIZED_FIELD_NUMBER: builtins.int
    materialized: builtins.str
    def __init__(
        self,
        *,
        materialized: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized"]) -> None: ...

global___UnsupportedConstraintMaterialization = UnsupportedConstraintMaterialization

@typing.final
class UnsupportedConstraintMaterializationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnsupportedConstraintMaterialization: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnsupportedConstraintMaterialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnsupportedConstraintMaterializationMsg = UnsupportedConstraintMaterializationMsg

@typing.final
class ParseInlineNodeError(google.protobuf.message.Message):
    """I069"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        exc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "node_info", b"node_info"]) -> None: ...

global___ParseInlineNodeError = ParseInlineNodeError

@typing.final
class ParseInlineNodeErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ParseInlineNodeError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ParseInlineNodeError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ParseInlineNodeErrorMsg = ParseInlineNodeErrorMsg

@typing.final
class SemanticValidationFailure(google.protobuf.message.Message):
    """I070"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___SemanticValidationFailure = SemanticValidationFailure

@typing.final
class SemanticValidationFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SemanticValidationFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SemanticValidationFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SemanticValidationFailureMsg = SemanticValidationFailureMsg

@typing.final
class UnversionedBreakingChange(google.protobuf.message.Message):
    """I071"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BREAKING_CHANGES_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    MODEL_FILE_PATH_FIELD_NUMBER: builtins.int
    CONTRACT_ENFORCED_DISABLED_FIELD_NUMBER: builtins.int
    COLUMNS_REMOVED_FIELD_NUMBER: builtins.int
    COLUMN_TYPE_CHANGES_FIELD_NUMBER: builtins.int
    ENFORCED_COLUMN_CONSTRAINT_REMOVED_FIELD_NUMBER: builtins.int
    ENFORCED_MODEL_CONSTRAINT_REMOVED_FIELD_NUMBER: builtins.int
    MATERIALIZATION_CHANGED_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    model_file_path: builtins.str
    contract_enforced_disabled: builtins.bool
    @property
    def breaking_changes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def columns_removed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def column_type_changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ColumnType]: ...
    @property
    def enforced_column_constraint_removed(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ColumnConstraint]: ...
    @property
    def enforced_model_constraint_removed(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelConstraint]: ...
    @property
    def materialization_changed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        breaking_changes: collections.abc.Iterable[builtins.str] | None = ...,
        model_name: builtins.str = ...,
        model_file_path: builtins.str = ...,
        contract_enforced_disabled: builtins.bool = ...,
        columns_removed: collections.abc.Iterable[builtins.str] | None = ...,
        column_type_changes: collections.abc.Iterable[global___ColumnType] | None = ...,
        enforced_column_constraint_removed: collections.abc.Iterable[global___ColumnConstraint] | None = ...,
        enforced_model_constraint_removed: collections.abc.Iterable[global___ModelConstraint] | None = ...,
        materialization_changed: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["breaking_changes", b"breaking_changes", "column_type_changes", b"column_type_changes", "columns_removed", b"columns_removed", "contract_enforced_disabled", b"contract_enforced_disabled", "enforced_column_constraint_removed", b"enforced_column_constraint_removed", "enforced_model_constraint_removed", b"enforced_model_constraint_removed", "materialization_changed", b"materialization_changed", "model_file_path", b"model_file_path", "model_name", b"model_name"]) -> None: ...

global___UnversionedBreakingChange = UnversionedBreakingChange

@typing.final
class UnversionedBreakingChangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___UnversionedBreakingChange: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___UnversionedBreakingChange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___UnversionedBreakingChangeMsg = UnversionedBreakingChangeMsg

@typing.final
class WarnStateTargetEqual(google.protobuf.message.Message):
    """I072"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_PATH_FIELD_NUMBER: builtins.int
    state_path: builtins.str
    def __init__(
        self,
        *,
        state_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["state_path", b"state_path"]) -> None: ...

global___WarnStateTargetEqual = WarnStateTargetEqual

@typing.final
class WarnStateTargetEqualMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___WarnStateTargetEqual: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___WarnStateTargetEqual | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___WarnStateTargetEqualMsg = WarnStateTargetEqualMsg

@typing.final
class FreshnessConfigProblem(google.protobuf.message.Message):
    """I073"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___FreshnessConfigProblem = FreshnessConfigProblem

@typing.final
class FreshnessConfigProblemMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FreshnessConfigProblem: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FreshnessConfigProblem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FreshnessConfigProblemMsg = FreshnessConfigProblemMsg

@typing.final
class MicrobatchModelNoEventTimeInputs(google.protobuf.message.Message):
    """I074"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name"]) -> None: ...

global___MicrobatchModelNoEventTimeInputs = MicrobatchModelNoEventTimeInputs

@typing.final
class MicrobatchModelNoEventTimeInputsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MicrobatchModelNoEventTimeInputs: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MicrobatchModelNoEventTimeInputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MicrobatchModelNoEventTimeInputsMsg = MicrobatchModelNoEventTimeInputsMsg

@typing.final
class InvalidConcurrentBatchesConfig(google.protobuf.message.Message):
    """I075"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MODELS_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    num_models: builtins.int
    adapter_type: builtins.str
    def __init__(
        self,
        *,
        num_models: builtins.int = ...,
        adapter_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "num_models", b"num_models"]) -> None: ...

global___InvalidConcurrentBatchesConfig = InvalidConcurrentBatchesConfig

@typing.final
class InvalidConcurrentBatchesConfigMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidConcurrentBatchesConfig: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidConcurrentBatchesConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidConcurrentBatchesConfigMsg = InvalidConcurrentBatchesConfigMsg

@typing.final
class InvalidMacroAnnotation(google.protobuf.message.Message):
    """I076"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    MACRO_UNIQUE_ID_FIELD_NUMBER: builtins.int
    MACRO_FILE_PATH_FIELD_NUMBER: builtins.int
    msg: builtins.str
    macro_unique_id: builtins.str
    macro_file_path: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        macro_unique_id: builtins.str = ...,
        macro_file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["macro_file_path", b"macro_file_path", "macro_unique_id", b"macro_unique_id", "msg", b"msg"]) -> None: ...

global___InvalidMacroAnnotation = InvalidMacroAnnotation

@typing.final
class InvalidMacroAnnotationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InvalidMacroAnnotation: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InvalidMacroAnnotation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InvalidMacroAnnotationMsg = InvalidMacroAnnotationMsg

@typing.final
class GitSparseCheckoutSubdirectory(google.protobuf.message.Message):
    """M - Deps generation

    M001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBDIR_FIELD_NUMBER: builtins.int
    subdir: builtins.str
    def __init__(
        self,
        *,
        subdir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subdir", b"subdir"]) -> None: ...

global___GitSparseCheckoutSubdirectory = GitSparseCheckoutSubdirectory

@typing.final
class GitSparseCheckoutSubdirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitSparseCheckoutSubdirectory: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitSparseCheckoutSubdirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitSparseCheckoutSubdirectoryMsg = GitSparseCheckoutSubdirectoryMsg

@typing.final
class GitProgressCheckoutRevision(google.protobuf.message.Message):
    """M002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REVISION_FIELD_NUMBER: builtins.int
    revision: builtins.str
    def __init__(
        self,
        *,
        revision: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["revision", b"revision"]) -> None: ...

global___GitProgressCheckoutRevision = GitProgressCheckoutRevision

@typing.final
class GitProgressCheckoutRevisionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitProgressCheckoutRevision: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitProgressCheckoutRevision | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitProgressCheckoutRevisionMsg = GitProgressCheckoutRevisionMsg

@typing.final
class GitProgressUpdatingExistingDependency(google.protobuf.message.Message):
    """M003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

global___GitProgressUpdatingExistingDependency = GitProgressUpdatingExistingDependency

@typing.final
class GitProgressUpdatingExistingDependencyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitProgressUpdatingExistingDependency: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitProgressUpdatingExistingDependency | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitProgressUpdatingExistingDependencyMsg = GitProgressUpdatingExistingDependencyMsg

@typing.final
class GitProgressPullingNewDependency(google.protobuf.message.Message):
    """M004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

global___GitProgressPullingNewDependency = GitProgressPullingNewDependency

@typing.final
class GitProgressPullingNewDependencyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitProgressPullingNewDependency: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitProgressPullingNewDependency | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitProgressPullingNewDependencyMsg = GitProgressPullingNewDependencyMsg

@typing.final
class GitNothingToDo(google.protobuf.message.Message):
    """M005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA_FIELD_NUMBER: builtins.int
    sha: builtins.str
    def __init__(
        self,
        *,
        sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sha", b"sha"]) -> None: ...

global___GitNothingToDo = GitNothingToDo

@typing.final
class GitNothingToDoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitNothingToDo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitNothingToDo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitNothingToDoMsg = GitNothingToDoMsg

@typing.final
class GitProgressUpdatedCheckoutRange(google.protobuf.message.Message):
    """M006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_SHA_FIELD_NUMBER: builtins.int
    END_SHA_FIELD_NUMBER: builtins.int
    start_sha: builtins.str
    end_sha: builtins.str
    def __init__(
        self,
        *,
        start_sha: builtins.str = ...,
        end_sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_sha", b"end_sha", "start_sha", b"start_sha"]) -> None: ...

global___GitProgressUpdatedCheckoutRange = GitProgressUpdatedCheckoutRange

@typing.final
class GitProgressUpdatedCheckoutRangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitProgressUpdatedCheckoutRange: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitProgressUpdatedCheckoutRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitProgressUpdatedCheckoutRangeMsg = GitProgressUpdatedCheckoutRangeMsg

@typing.final
class GitProgressCheckedOutAt(google.protobuf.message.Message):
    """M007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_SHA_FIELD_NUMBER: builtins.int
    end_sha: builtins.str
    def __init__(
        self,
        *,
        end_sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_sha", b"end_sha"]) -> None: ...

global___GitProgressCheckedOutAt = GitProgressCheckedOutAt

@typing.final
class GitProgressCheckedOutAtMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GitProgressCheckedOutAt: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GitProgressCheckedOutAt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GitProgressCheckedOutAtMsg = GitProgressCheckedOutAtMsg

@typing.final
class RegistryProgressGETRequest(google.protobuf.message.Message):
    """M008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RegistryProgressGETRequest = RegistryProgressGETRequest

@typing.final
class RegistryProgressGETRequestMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryProgressGETRequest: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryProgressGETRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryProgressGETRequestMsg = RegistryProgressGETRequestMsg

@typing.final
class RegistryProgressGETResponse(google.protobuf.message.Message):
    """M009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    RESP_CODE_FIELD_NUMBER: builtins.int
    url: builtins.str
    resp_code: builtins.int
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        resp_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resp_code", b"resp_code", "url", b"url"]) -> None: ...

global___RegistryProgressGETResponse = RegistryProgressGETResponse

@typing.final
class RegistryProgressGETResponseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryProgressGETResponse: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryProgressGETResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryProgressGETResponseMsg = RegistryProgressGETResponseMsg

@typing.final
class SelectorReportInvalidSelector(google.protobuf.message.Message):
    """M010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_SELECTORS_FIELD_NUMBER: builtins.int
    SPEC_METHOD_FIELD_NUMBER: builtins.int
    RAW_SPEC_FIELD_NUMBER: builtins.int
    valid_selectors: builtins.str
    spec_method: builtins.str
    raw_spec: builtins.str
    def __init__(
        self,
        *,
        valid_selectors: builtins.str = ...,
        spec_method: builtins.str = ...,
        raw_spec: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["raw_spec", b"raw_spec", "spec_method", b"spec_method", "valid_selectors", b"valid_selectors"]) -> None: ...

global___SelectorReportInvalidSelector = SelectorReportInvalidSelector

@typing.final
class SelectorReportInvalidSelectorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SelectorReportInvalidSelector: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SelectorReportInvalidSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SelectorReportInvalidSelectorMsg = SelectorReportInvalidSelectorMsg

@typing.final
class DepsNoPackagesFound(google.protobuf.message.Message):
    """Skipped M011 and M012

    M013
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DepsNoPackagesFound = DepsNoPackagesFound

@typing.final
class DepsNoPackagesFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsNoPackagesFound: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsNoPackagesFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsNoPackagesFoundMsg = DepsNoPackagesFoundMsg

@typing.final
class DepsStartPackageInstall(google.protobuf.message.Message):
    """M014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name"]) -> None: ...

global___DepsStartPackageInstall = DepsStartPackageInstall

@typing.final
class DepsStartPackageInstallMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsStartPackageInstall: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsStartPackageInstall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsStartPackageInstallMsg = DepsStartPackageInstallMsg

@typing.final
class DepsInstallInfo(google.protobuf.message.Message):
    """M015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_NAME_FIELD_NUMBER: builtins.int
    version_name: builtins.str
    def __init__(
        self,
        *,
        version_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version_name", b"version_name"]) -> None: ...

global___DepsInstallInfo = DepsInstallInfo

@typing.final
class DepsInstallInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsInstallInfo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsInstallInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsInstallInfoMsg = DepsInstallInfoMsg

@typing.final
class DepsUpdateAvailable(google.protobuf.message.Message):
    """M016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_LATEST_FIELD_NUMBER: builtins.int
    version_latest: builtins.str
    def __init__(
        self,
        *,
        version_latest: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version_latest", b"version_latest"]) -> None: ...

global___DepsUpdateAvailable = DepsUpdateAvailable

@typing.final
class DepsUpdateAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsUpdateAvailable: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsUpdateAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsUpdateAvailableMsg = DepsUpdateAvailableMsg

@typing.final
class DepsUpToDate(google.protobuf.message.Message):
    """M017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DepsUpToDate = DepsUpToDate

@typing.final
class DepsUpToDateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsUpToDate: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsUpToDate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsUpToDateMsg = DepsUpToDateMsg

@typing.final
class DepsListSubdirectory(google.protobuf.message.Message):
    """M018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBDIRECTORY_FIELD_NUMBER: builtins.int
    subdirectory: builtins.str
    def __init__(
        self,
        *,
        subdirectory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subdirectory", b"subdirectory"]) -> None: ...

global___DepsListSubdirectory = DepsListSubdirectory

@typing.final
class DepsListSubdirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsListSubdirectory: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsListSubdirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsListSubdirectoryMsg = DepsListSubdirectoryMsg

@typing.final
class DepsNotifyUpdatesAvailable(google.protobuf.message.Message):
    """M019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["packages", b"packages"]) -> None: ...

global___DepsNotifyUpdatesAvailable = DepsNotifyUpdatesAvailable

@typing.final
class DepsNotifyUpdatesAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsNotifyUpdatesAvailable: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsNotifyUpdatesAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsNotifyUpdatesAvailableMsg = DepsNotifyUpdatesAvailableMsg

@typing.final
class RegistryIndexProgressGETRequest(google.protobuf.message.Message):
    """M022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RegistryIndexProgressGETRequest = RegistryIndexProgressGETRequest

@typing.final
class RegistryIndexProgressGETRequestMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryIndexProgressGETRequest: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryIndexProgressGETRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryIndexProgressGETRequestMsg = RegistryIndexProgressGETRequestMsg

@typing.final
class RegistryIndexProgressGETResponse(google.protobuf.message.Message):
    """M023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    RESP_CODE_FIELD_NUMBER: builtins.int
    url: builtins.str
    resp_code: builtins.int
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        resp_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resp_code", b"resp_code", "url", b"url"]) -> None: ...

global___RegistryIndexProgressGETResponse = RegistryIndexProgressGETResponse

@typing.final
class RegistryIndexProgressGETResponseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryIndexProgressGETResponse: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryIndexProgressGETResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryIndexProgressGETResponseMsg = RegistryIndexProgressGETResponseMsg

@typing.final
class RegistryResponseUnexpectedType(google.protobuf.message.Message):
    """M024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

global___RegistryResponseUnexpectedType = RegistryResponseUnexpectedType

@typing.final
class RegistryResponseUnexpectedTypeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryResponseUnexpectedType: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryResponseUnexpectedType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryResponseUnexpectedTypeMsg = RegistryResponseUnexpectedTypeMsg

@typing.final
class RegistryResponseMissingTopKeys(google.protobuf.message.Message):
    """M025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

global___RegistryResponseMissingTopKeys = RegistryResponseMissingTopKeys

@typing.final
class RegistryResponseMissingTopKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryResponseMissingTopKeys: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryResponseMissingTopKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryResponseMissingTopKeysMsg = RegistryResponseMissingTopKeysMsg

@typing.final
class RegistryResponseMissingNestedKeys(google.protobuf.message.Message):
    """M026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

global___RegistryResponseMissingNestedKeys = RegistryResponseMissingNestedKeys

@typing.final
class RegistryResponseMissingNestedKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryResponseMissingNestedKeys: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryResponseMissingNestedKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryResponseMissingNestedKeysMsg = RegistryResponseMissingNestedKeysMsg

@typing.final
class RegistryResponseExtraNestedKeys(google.protobuf.message.Message):
    """M027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

global___RegistryResponseExtraNestedKeys = RegistryResponseExtraNestedKeys

@typing.final
class RegistryResponseExtraNestedKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RegistryResponseExtraNestedKeys: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RegistryResponseExtraNestedKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RegistryResponseExtraNestedKeysMsg = RegistryResponseExtraNestedKeysMsg

@typing.final
class DepsSetDownloadDirectory(google.protobuf.message.Message):
    """M028"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___DepsSetDownloadDirectory = DepsSetDownloadDirectory

@typing.final
class DepsSetDownloadDirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsSetDownloadDirectory: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsSetDownloadDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsSetDownloadDirectoryMsg = DepsSetDownloadDirectoryMsg

@typing.final
class DepsUnpinned(google.protobuf.message.Message):
    """M029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REVISION_FIELD_NUMBER: builtins.int
    GIT_FIELD_NUMBER: builtins.int
    revision: builtins.str
    git: builtins.str
    def __init__(
        self,
        *,
        revision: builtins.str = ...,
        git: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["git", b"git", "revision", b"revision"]) -> None: ...

global___DepsUnpinned = DepsUnpinned

@typing.final
class DepsUnpinnedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsUnpinned: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsUnpinned | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsUnpinnedMsg = DepsUnpinnedMsg

@typing.final
class NoNodesForSelectionCriteria(google.protobuf.message.Message):
    """M030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_RAW_FIELD_NUMBER: builtins.int
    spec_raw: builtins.str
    def __init__(
        self,
        *,
        spec_raw: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["spec_raw", b"spec_raw"]) -> None: ...

global___NoNodesForSelectionCriteria = NoNodesForSelectionCriteria

@typing.final
class NoNodesForSelectionCriteriaMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NoNodesForSelectionCriteria: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NoNodesForSelectionCriteria | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NoNodesForSelectionCriteriaMsg = NoNodesForSelectionCriteriaMsg

@typing.final
class DepsLockUpdating(google.protobuf.message.Message):
    """M031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_FILEPATH_FIELD_NUMBER: builtins.int
    lock_filepath: builtins.str
    def __init__(
        self,
        *,
        lock_filepath: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lock_filepath", b"lock_filepath"]) -> None: ...

global___DepsLockUpdating = DepsLockUpdating

@typing.final
class DepsLockUpdatingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsLockUpdating: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsLockUpdating | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsLockUpdatingMsg = DepsLockUpdatingMsg

@typing.final
class DepsAddPackage(google.protobuf.message.Message):
    """M032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PACKAGES_FILEPATH_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    version: builtins.str
    packages_filepath: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        version: builtins.str = ...,
        packages_filepath: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name", "packages_filepath", b"packages_filepath", "version", b"version"]) -> None: ...

global___DepsAddPackage = DepsAddPackage

@typing.final
class DepsAddPackageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsAddPackage: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsAddPackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsAddPackageMsg = DepsAddPackageMsg

@typing.final
class DepsFoundDuplicatePackage(google.protobuf.message.Message):
    """M033"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RemovedPackageEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    REMOVED_PACKAGE_FIELD_NUMBER: builtins.int
    @property
    def removed_package(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        removed_package: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["removed_package", b"removed_package"]) -> None: ...

global___DepsFoundDuplicatePackage = DepsFoundDuplicatePackage

@typing.final
class DepsFoundDuplicatePackageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsFoundDuplicatePackage: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsFoundDuplicatePackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsFoundDuplicatePackageMsg = DepsFoundDuplicatePackageMsg

@typing.final
class DepsVersionMissing(google.protobuf.message.Message):
    """M034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    source: builtins.str
    def __init__(
        self,
        *,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source", b"source"]) -> None: ...

global___DepsVersionMissing = DepsVersionMissing

@typing.final
class DepsVersionMissingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsVersionMissing: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsVersionMissing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsVersionMissingMsg = DepsVersionMissingMsg

@typing.final
class DepsScrubbedPackageName(google.protobuf.message.Message):
    """M035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name"]) -> None: ...

global___DepsScrubbedPackageName = DepsScrubbedPackageName

@typing.final
class DepsScrubbedPackageNameMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsScrubbedPackageName: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsScrubbedPackageName | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsScrubbedPackageNameMsg = DepsScrubbedPackageNameMsg

@typing.final
class ArtifactWritten(google.protobuf.message.Message):
    """P - Artifacts

    P001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_TYPE_FIELD_NUMBER: builtins.int
    ARTIFACT_PATH_FIELD_NUMBER: builtins.int
    artifact_type: builtins.str
    artifact_path: builtins.str
    def __init__(
        self,
        *,
        artifact_type: builtins.str = ...,
        artifact_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_path", b"artifact_path", "artifact_type", b"artifact_type"]) -> None: ...

global___ArtifactWritten = ArtifactWritten

@typing.final
class ArtifactWrittenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ArtifactWritten: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ArtifactWritten | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ArtifactWrittenMsg = ArtifactWrittenMsg

@typing.final
class RunningOperationCaughtError(google.protobuf.message.Message):
    """Q - Node execution

    Q001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

global___RunningOperationCaughtError = RunningOperationCaughtError

@typing.final
class RunningOperationCaughtErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunningOperationCaughtError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunningOperationCaughtError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunningOperationCaughtErrorMsg = RunningOperationCaughtErrorMsg

@typing.final
class CompileComplete(google.protobuf.message.Message):
    """Q002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CompileComplete = CompileComplete

@typing.final
class CompileCompleteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CompileComplete: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CompileComplete | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CompileCompleteMsg = CompileCompleteMsg

@typing.final
class FreshnessCheckComplete(google.protobuf.message.Message):
    """Q003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FreshnessCheckComplete = FreshnessCheckComplete

@typing.final
class FreshnessCheckCompleteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FreshnessCheckComplete: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FreshnessCheckComplete | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FreshnessCheckCompleteMsg = FreshnessCheckCompleteMsg

@typing.final
class SeedHeader(google.protobuf.message.Message):
    """Q004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    header: builtins.str
    def __init__(
        self,
        *,
        header: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["header", b"header"]) -> None: ...

global___SeedHeader = SeedHeader

@typing.final
class SeedHeaderMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SeedHeader: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SeedHeader | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SeedHeaderMsg = SeedHeaderMsg

@typing.final
class SQLRunnerException(google.protobuf.message.Message):
    """Skipped Q005

    Q006
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    exc: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

global___SQLRunnerException = SQLRunnerException

@typing.final
class SQLRunnerExceptionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SQLRunnerException: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SQLRunnerException | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SQLRunnerExceptionMsg = SQLRunnerExceptionMsg

@typing.final
class Group(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OwnerEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    name: builtins.str
    package_name: builtins.str
    @property
    def owner(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        package_name: builtins.str = ...,
        owner: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "owner", b"owner", "package_name", b"package_name"]) -> None: ...

global___Group = Group

@typing.final
class LogTestResult(google.protobuf.message.Message):
    """Q007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    NUM_MODELS_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    NUM_FAILURES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    ATTACHED_NODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    status: builtins.str
    index: builtins.int
    num_models: builtins.int
    execution_time: builtins.float
    num_failures: builtins.int
    attached_node: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        name: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        num_models: builtins.int = ...,
        execution_time: builtins.float = ...,
        num_failures: builtins.int = ...,
        group: global___Group | None = ...,
        attached_node: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attached_node", b"attached_node", "execution_time", b"execution_time", "group", b"group", "index", b"index", "name", b"name", "node_info", b"node_info", "num_failures", b"num_failures", "num_models", b"num_models", "status", b"status"]) -> None: ...

global___LogTestResult = LogTestResult

@typing.final
class LogTestResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogTestResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogTestResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogTestResultMsg = LogTestResultMsg

@typing.final
class LogNodeResult(google.protobuf.message.Message):
    """Q008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "index", b"index", "msg", b"msg", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

global___LogNodeResult = LogNodeResult

@typing.final
class LogNodeResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogNodeResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogNodeResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogNodeResultMsg = LogNodeResultMsg

@typing.final
class LogStartLine(google.protobuf.message.Message):
    """Skipped Q009, Q010

    Q011
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    description: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "index", b"index", "node_info", b"node_info", "total", b"total"]) -> None: ...

global___LogStartLine = LogStartLine

@typing.final
class LogStartLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogStartLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogStartLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogStartLineMsg = LogStartLineMsg

@typing.final
class LogModelResult(google.protobuf.message.Message):
    """Q012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

global___LogModelResult = LogModelResult

@typing.final
class LogModelResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogModelResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogModelResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogModelResultMsg = LogModelResultMsg

@typing.final
class LogSnapshotResult(google.protobuf.message.Message):
    """skipped Q013, Q014

    Q015
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CfgEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    CFG_FIELD_NUMBER: builtins.int
    RESULT_MESSAGE_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    result_message: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def cfg(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        cfg: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        result_message: builtins.str = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cfg", b"cfg", "description", b"description", "execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "result_message", b"result_message", "status", b"status", "total", b"total"]) -> None: ...

global___LogSnapshotResult = LogSnapshotResult

@typing.final
class LogSnapshotResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogSnapshotResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogSnapshotResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogSnapshotResultMsg = LogSnapshotResultMsg

@typing.final
class LogSeedResult(google.protobuf.message.Message):
    """Q016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESULT_MESSAGE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    status: builtins.str
    result_message: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    schema: builtins.str
    relation: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        status: builtins.str = ...,
        result_message: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        schema: builtins.str = ...,
        relation: builtins.str = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "relation", b"relation", "result_message", b"result_message", "schema", b"schema", "status", b"status", "total", b"total"]) -> None: ...

global___LogSeedResult = LogSeedResult

@typing.final
class LogSeedResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogSeedResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogSeedResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogSeedResultMsg = LogSeedResultMsg

@typing.final
class LogFreshnessResult(google.protobuf.message.Message):
    """Skipped Q017

    Q018
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    SOURCE_NAME_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    source_name: builtins.str
    table_name: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        source_name: builtins.str = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "source_name", b"source_name", "status", b"status", "table_name", b"table_name", "total", b"total"]) -> None: ...

global___LogFreshnessResult = LogFreshnessResult

@typing.final
class LogFreshnessResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogFreshnessResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogFreshnessResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogFreshnessResultMsg = LogFreshnessResultMsg

@typing.final
class LogNodeNoOpResult(google.protobuf.message.Message):
    """Q019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

global___LogNodeNoOpResult = LogNodeNoOpResult

@typing.final
class LogNodeNoOpResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogNodeNoOpResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogNodeNoOpResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogNodeNoOpResultMsg = LogNodeNoOpResultMsg

@typing.final
class LogCancelLine(google.protobuf.message.Message):
    """Skipped Q020, Q021

    Q022
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

global___LogCancelLine = LogCancelLine

@typing.final
class LogCancelLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogCancelLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogCancelLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogCancelLineMsg = LogCancelLineMsg

@typing.final
class DefaultSelector(google.protobuf.message.Message):
    """Q023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DefaultSelector = DefaultSelector

@typing.final
class DefaultSelectorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DefaultSelector: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DefaultSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DefaultSelectorMsg = DefaultSelectorMsg

@typing.final
class NodeStart(google.protobuf.message.Message):
    """Q024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

global___NodeStart = NodeStart

@typing.final
class NodeStartMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeStart: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeStart | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeStartMsg = NodeStartMsg

@typing.final
class NodeFinished(google.protobuf.message.Message):
    """Q025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    RUN_RESULT_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def run_result(self) -> global___RunResultMsg: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        run_result: global___RunResultMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info", "run_result", b"run_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "run_result", b"run_result"]) -> None: ...

global___NodeFinished = NodeFinished

@typing.final
class NodeFinishedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeFinished: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeFinished | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeFinishedMsg = NodeFinishedMsg

@typing.final
class QueryCancelationUnsupported(google.protobuf.message.Message):
    """Q026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

global___QueryCancelationUnsupported = QueryCancelationUnsupported

@typing.final
class QueryCancelationUnsupportedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___QueryCancelationUnsupported: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___QueryCancelationUnsupported | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___QueryCancelationUnsupportedMsg = QueryCancelationUnsupportedMsg

@typing.final
class ConcurrencyLine(google.protobuf.message.Message):
    """Q027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_THREADS_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    num_threads: builtins.int
    target_name: builtins.str
    node_count: builtins.int
    def __init__(
        self,
        *,
        num_threads: builtins.int = ...,
        target_name: builtins.str = ...,
        node_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_count", b"node_count", "num_threads", b"num_threads", "target_name", b"target_name"]) -> None: ...

global___ConcurrencyLine = ConcurrencyLine

@typing.final
class ConcurrencyLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConcurrencyLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConcurrencyLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConcurrencyLineMsg = ConcurrencyLineMsg

@typing.final
class WritingInjectedSQLForNode(google.protobuf.message.Message):
    """Q029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

global___WritingInjectedSQLForNode = WritingInjectedSQLForNode

@typing.final
class WritingInjectedSQLForNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___WritingInjectedSQLForNode: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___WritingInjectedSQLForNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___WritingInjectedSQLForNodeMsg = WritingInjectedSQLForNodeMsg

@typing.final
class NodeCompiling(google.protobuf.message.Message):
    """Q030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

global___NodeCompiling = NodeCompiling

@typing.final
class NodeCompilingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeCompiling: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeCompiling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeCompilingMsg = NodeCompilingMsg

@typing.final
class NodeExecuting(google.protobuf.message.Message):
    """Q031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

global___NodeExecuting = NodeExecuting

@typing.final
class NodeExecutingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeExecuting: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeExecuting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeExecutingMsg = NodeExecutingMsg

@typing.final
class LogHookStartLine(google.protobuf.message.Message):
    """Q032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    statement: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        statement: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "node_info", b"node_info", "statement", b"statement", "total", b"total"]) -> None: ...

global___LogHookStartLine = LogHookStartLine

@typing.final
class LogHookStartLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogHookStartLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogHookStartLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogHookStartLineMsg = LogHookStartLineMsg

@typing.final
class LogHookEndLine(google.protobuf.message.Message):
    """Q033"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    statement: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        statement: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "statement", b"statement", "status", b"status", "total", b"total"]) -> None: ...

global___LogHookEndLine = LogHookEndLine

@typing.final
class LogHookEndLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogHookEndLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogHookEndLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogHookEndLineMsg = LogHookEndLineMsg

@typing.final
class SkippingDetails(google.protobuf.message.Message):
    """Q034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    schema: builtins.str
    node_name: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        resource_type: builtins.str = ...,
        schema: builtins.str = ...,
        node_name: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "index", b"index", "node_info", b"node_info", "node_name", b"node_name", "resource_type", b"resource_type", "schema", b"schema", "total", b"total"]) -> None: ...

global___SkippingDetails = SkippingDetails

@typing.final
class SkippingDetailsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SkippingDetails: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SkippingDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SkippingDetailsMsg = SkippingDetailsMsg

@typing.final
class NothingToDo(google.protobuf.message.Message):
    """Q035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NothingToDo = NothingToDo

@typing.final
class NothingToDoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NothingToDo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NothingToDo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NothingToDoMsg = NothingToDoMsg

@typing.final
class RunningOperationUncaughtError(google.protobuf.message.Message):
    """Q036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

global___RunningOperationUncaughtError = RunningOperationUncaughtError

@typing.final
class RunningOperationUncaughtErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunningOperationUncaughtError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunningOperationUncaughtError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunningOperationUncaughtErrorMsg = RunningOperationUncaughtErrorMsg

@typing.final
class EndRunResult(google.protobuf.message.Message):
    """Q037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    ELAPSED_TIME_FIELD_NUMBER: builtins.int
    GENERATED_AT_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    elapsed_time: builtins.float
    success: builtins.bool
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunResultMsg]: ...
    @property
    def generated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___RunResultMsg] | None = ...,
        elapsed_time: builtins.float = ...,
        generated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        success: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["generated_at", b"generated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["elapsed_time", b"elapsed_time", "generated_at", b"generated_at", "results", b"results", "success", b"success"]) -> None: ...

global___EndRunResult = EndRunResult

@typing.final
class EndRunResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___EndRunResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___EndRunResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___EndRunResultMsg = EndRunResultMsg

@typing.final
class NoNodesSelected(google.protobuf.message.Message):
    """Q038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoNodesSelected = NoNodesSelected

@typing.final
class NoNodesSelectedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NoNodesSelected: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NoNodesSelected | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NoNodesSelectedMsg = NoNodesSelectedMsg

@typing.final
class CommandCompleted(google.protobuf.message.Message):
    """Q039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    command: builtins.str
    success: builtins.bool
    elapsed: builtins.float
    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        command: builtins.str = ...,
        success: builtins.bool = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        elapsed: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["command", b"command", "completed_at", b"completed_at", "elapsed", b"elapsed", "success", b"success"]) -> None: ...

global___CommandCompleted = CommandCompleted

@typing.final
class CommandCompletedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CommandCompleted: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CommandCompleted | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CommandCompletedMsg = CommandCompletedMsg

@typing.final
class ShowNode(google.protobuf.message.Message):
    """Q041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    IS_INLINE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    QUIET_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    preview: builtins.str
    is_inline: builtins.bool
    output_format: builtins.str
    unique_id: builtins.str
    quiet: builtins.bool
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        preview: builtins.str = ...,
        is_inline: builtins.bool = ...,
        output_format: builtins.str = ...,
        unique_id: builtins.str = ...,
        quiet: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_inline", b"is_inline", "node_name", b"node_name", "output_format", b"output_format", "preview", b"preview", "quiet", b"quiet", "unique_id", b"unique_id"]) -> None: ...

global___ShowNode = ShowNode

@typing.final
class ShowNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ShowNode: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ShowNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ShowNodeMsg = ShowNodeMsg

@typing.final
class CompiledNode(google.protobuf.message.Message):
    """Q042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    COMPILED_FIELD_NUMBER: builtins.int
    IS_INLINE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    QUIET_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    compiled: builtins.str
    is_inline: builtins.bool
    output_format: builtins.str
    unique_id: builtins.str
    quiet: builtins.bool
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        compiled: builtins.str = ...,
        is_inline: builtins.bool = ...,
        output_format: builtins.str = ...,
        unique_id: builtins.str = ...,
        quiet: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compiled", b"compiled", "is_inline", b"is_inline", "node_name", b"node_name", "output_format", b"output_format", "quiet", b"quiet", "unique_id", b"unique_id"]) -> None: ...

global___CompiledNode = CompiledNode

@typing.final
class CompiledNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CompiledNode: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CompiledNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CompiledNodeMsg = CompiledNodeMsg

@typing.final
class SnapshotTimestampWarning(google.protobuf.message.Message):
    """Q043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_TIME_DATA_TYPE_FIELD_NUMBER: builtins.int
    UPDATED_AT_DATA_TYPE_FIELD_NUMBER: builtins.int
    snapshot_time_data_type: builtins.str
    updated_at_data_type: builtins.str
    def __init__(
        self,
        *,
        snapshot_time_data_type: builtins.str = ...,
        updated_at_data_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_time_data_type", b"snapshot_time_data_type", "updated_at_data_type", b"updated_at_data_type"]) -> None: ...

global___SnapshotTimestampWarning = SnapshotTimestampWarning

@typing.final
class SnapshotTimestampWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SnapshotTimestampWarning: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SnapshotTimestampWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SnapshotTimestampWarningMsg = SnapshotTimestampWarningMsg

@typing.final
class MicrobatchExecutionDebug(google.protobuf.message.Message):
    """Q044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___MicrobatchExecutionDebug = MicrobatchExecutionDebug

@typing.final
class MicrobatchExecutionDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MicrobatchExecutionDebug: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MicrobatchExecutionDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MicrobatchExecutionDebugMsg = MicrobatchExecutionDebugMsg

@typing.final
class LogStartBatch(google.protobuf.message.Message):
    """Q045"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BATCH_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    description: builtins.str
    batch_index: builtins.int
    total_batches: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        batch_index: builtins.int = ...,
        total_batches: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_index", b"batch_index", "description", b"description", "node_info", b"node_info", "total_batches", b"total_batches"]) -> None: ...

global___LogStartBatch = LogStartBatch

@typing.final
class LogStartBatchMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogStartBatch: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogStartBatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogStartBatchMsg = LogStartBatchMsg

@typing.final
class LogBatchResult(google.protobuf.message.Message):
    """Q046"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BATCH_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    batch_index: builtins.int
    total_batches: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        batch_index: builtins.int = ...,
        total_batches: builtins.int = ...,
        execution_time: builtins.float = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_index", b"batch_index", "description", b"description", "execution_time", b"execution_time", "group", b"group", "node_info", b"node_info", "status", b"status", "total_batches", b"total_batches"]) -> None: ...

global___LogBatchResult = LogBatchResult

@typing.final
class LogBatchResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogBatchResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogBatchResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogBatchResultMsg = LogBatchResultMsg

@typing.final
class CatchableExceptionOnRun(google.protobuf.message.Message):
    """Skipped W001

    W002
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    exc: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

global___CatchableExceptionOnRun = CatchableExceptionOnRun

@typing.final
class CatchableExceptionOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CatchableExceptionOnRun: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CatchableExceptionOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CatchableExceptionOnRunMsg = CatchableExceptionOnRunMsg

@typing.final
class InternalErrorOnRun(google.protobuf.message.Message):
    """W003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PATH_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    build_path: builtins.str
    exc: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        build_path: builtins.str = ...,
        exc: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["build_path", b"build_path", "exc", b"exc", "node_info", b"node_info"]) -> None: ...

global___InternalErrorOnRun = InternalErrorOnRun

@typing.final
class InternalErrorOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___InternalErrorOnRun: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___InternalErrorOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___InternalErrorOnRunMsg = InternalErrorOnRunMsg

@typing.final
class GenericExceptionOnRun(google.protobuf.message.Message):
    """W004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PATH_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    build_path: builtins.str
    unique_id: builtins.str
    exc: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        build_path: builtins.str = ...,
        unique_id: builtins.str = ...,
        exc: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["build_path", b"build_path", "exc", b"exc", "node_info", b"node_info", "unique_id", b"unique_id"]) -> None: ...

global___GenericExceptionOnRun = GenericExceptionOnRun

@typing.final
class GenericExceptionOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___GenericExceptionOnRun: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___GenericExceptionOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___GenericExceptionOnRunMsg = GenericExceptionOnRunMsg

@typing.final
class NodeConnectionReleaseError(google.protobuf.message.Message):
    """W005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    exc: builtins.str
    exc_info: builtins.str
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_name", b"node_name"]) -> None: ...

global___NodeConnectionReleaseError = NodeConnectionReleaseError

@typing.final
class NodeConnectionReleaseErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___NodeConnectionReleaseError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___NodeConnectionReleaseError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___NodeConnectionReleaseErrorMsg = NodeConnectionReleaseErrorMsg

@typing.final
class FoundStats(google.protobuf.message.Message):
    """W006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAT_LINE_FIELD_NUMBER: builtins.int
    stat_line: builtins.str
    def __init__(
        self,
        *,
        stat_line: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stat_line", b"stat_line"]) -> None: ...

global___FoundStats = FoundStats

@typing.final
class FoundStatsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FoundStats: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FoundStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FoundStatsMsg = FoundStatsMsg

@typing.final
class MainKeyboardInterrupt(google.protobuf.message.Message):
    """Z - Misc

    Z001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MainKeyboardInterrupt = MainKeyboardInterrupt

@typing.final
class MainKeyboardInterruptMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainKeyboardInterrupt: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainKeyboardInterrupt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainKeyboardInterruptMsg = MainKeyboardInterruptMsg

@typing.final
class MainEncounteredError(google.protobuf.message.Message):
    """Z002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

global___MainEncounteredError = MainEncounteredError

@typing.final
class MainEncounteredErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainEncounteredError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainEncounteredError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainEncounteredErrorMsg = MainEncounteredErrorMsg

@typing.final
class MainStackTrace(google.protobuf.message.Message):
    """Z003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STACK_TRACE_FIELD_NUMBER: builtins.int
    stack_trace: builtins.str
    def __init__(
        self,
        *,
        stack_trace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stack_trace", b"stack_trace"]) -> None: ...

global___MainStackTrace = MainStackTrace

@typing.final
class MainStackTraceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MainStackTrace: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MainStackTrace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MainStackTraceMsg = MainStackTraceMsg

@typing.final
class TimingInfoCollected(google.protobuf.message.Message):
    """skipping Z004

    Z010
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    TIMING_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def timing_info(self) -> global___TimingInfoMsg: ...
    def __init__(
        self,
        *,
        node_info: global___NodeInfo | None = ...,
        timing_info: global___TimingInfoMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info", "timing_info", b"timing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "timing_info", b"timing_info"]) -> None: ...

global___TimingInfoCollected = TimingInfoCollected

@typing.final
class TimingInfoCollectedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___TimingInfoCollected: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___TimingInfoCollected | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___TimingInfoCollectedMsg = TimingInfoCollectedMsg

@typing.final
class LogDebugStackTrace(google.protobuf.message.Message):
    """Z011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

global___LogDebugStackTrace = LogDebugStackTrace

@typing.final
class LogDebugStackTraceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogDebugStackTrace: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogDebugStackTrace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogDebugStackTraceMsg = LogDebugStackTraceMsg

@typing.final
class CheckCleanPath(google.protobuf.message.Message):
    """Z012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___CheckCleanPath = CheckCleanPath

@typing.final
class CheckCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CheckCleanPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CheckCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CheckCleanPathMsg = CheckCleanPathMsg

@typing.final
class ConfirmCleanPath(google.protobuf.message.Message):
    """Z013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___ConfirmCleanPath = ConfirmCleanPath

@typing.final
class ConfirmCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ConfirmCleanPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ConfirmCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ConfirmCleanPathMsg = ConfirmCleanPathMsg

@typing.final
class ProtectedCleanPath(google.protobuf.message.Message):
    """Z014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___ProtectedCleanPath = ProtectedCleanPath

@typing.final
class ProtectedCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ProtectedCleanPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ProtectedCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ProtectedCleanPathMsg = ProtectedCleanPathMsg

@typing.final
class FinishedCleanPaths(google.protobuf.message.Message):
    """Z015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FinishedCleanPaths = FinishedCleanPaths

@typing.final
class FinishedCleanPathsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FinishedCleanPaths: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FinishedCleanPaths | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FinishedCleanPathsMsg = FinishedCleanPathsMsg

@typing.final
class OpenCommand(google.protobuf.message.Message):
    """Z016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_CMD_FIELD_NUMBER: builtins.int
    PROFILES_DIR_FIELD_NUMBER: builtins.int
    open_cmd: builtins.str
    profiles_dir: builtins.str
    def __init__(
        self,
        *,
        open_cmd: builtins.str = ...,
        profiles_dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["open_cmd", b"open_cmd", "profiles_dir", b"profiles_dir"]) -> None: ...

global___OpenCommand = OpenCommand

@typing.final
class OpenCommandMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___OpenCommand: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___OpenCommand | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___OpenCommandMsg = OpenCommandMsg

@typing.final
class ServingDocsPort(google.protobuf.message.Message):
    """Z018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    address: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "port", b"port"]) -> None: ...

global___ServingDocsPort = ServingDocsPort

@typing.final
class ServingDocsPortMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ServingDocsPort: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ServingDocsPort | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ServingDocsPortMsg = ServingDocsPortMsg

@typing.final
class ServingDocsAccessInfo(google.protobuf.message.Message):
    """Z019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    port: builtins.str
    def __init__(
        self,
        *,
        port: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port", b"port"]) -> None: ...

global___ServingDocsAccessInfo = ServingDocsAccessInfo

@typing.final
class ServingDocsAccessInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ServingDocsAccessInfo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ServingDocsAccessInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ServingDocsAccessInfoMsg = ServingDocsAccessInfoMsg

@typing.final
class ServingDocsExitInfo(google.protobuf.message.Message):
    """Z020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ServingDocsExitInfo = ServingDocsExitInfo

@typing.final
class ServingDocsExitInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ServingDocsExitInfo: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ServingDocsExitInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ServingDocsExitInfoMsg = ServingDocsExitInfoMsg

@typing.final
class RunResultWarning(google.protobuf.message.Message):
    """Z021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    node_name: builtins.str
    path: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        node_name: builtins.str = ...,
        path: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info", "node_name", b"node_name", "path", b"path", "resource_type", b"resource_type"]) -> None: ...

global___RunResultWarning = RunResultWarning

@typing.final
class RunResultWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunResultWarning: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunResultWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunResultWarningMsg = RunResultWarningMsg

@typing.final
class RunResultFailure(google.protobuf.message.Message):
    """Z022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    node_name: builtins.str
    path: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        node_name: builtins.str = ...,
        path: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info", "node_name", b"node_name", "path", b"path", "resource_type", b"resource_type"]) -> None: ...

global___RunResultFailure = RunResultFailure

@typing.final
class RunResultFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunResultFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunResultFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunResultFailureMsg = RunResultFailureMsg

@typing.final
class StatsLine(google.protobuf.message.Message):
    """Z023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StatsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATS_FIELD_NUMBER: builtins.int
    @property
    def stats(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]: ...
    def __init__(
        self,
        *,
        stats: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stats", b"stats"]) -> None: ...

global___StatsLine = StatsLine

@typing.final
class StatsLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___StatsLine: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___StatsLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___StatsLineMsg = StatsLineMsg

@typing.final
class RunResultError(google.protobuf.message.Message):
    """Z024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "msg", b"msg", "node_info", b"node_info"]) -> None: ...

global___RunResultError = RunResultError

@typing.final
class RunResultErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunResultError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunResultError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunResultErrorMsg = RunResultErrorMsg

@typing.final
class RunResultErrorNoMessage(google.protobuf.message.Message):
    """Z025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    status: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "status", b"status"]) -> None: ...

global___RunResultErrorNoMessage = RunResultErrorNoMessage

@typing.final
class RunResultErrorNoMessageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunResultErrorNoMessage: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunResultErrorNoMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunResultErrorNoMessageMsg = RunResultErrorNoMessageMsg

@typing.final
class SQLCompiledPath(google.protobuf.message.Message):
    """Z026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "path", b"path"]) -> None: ...

global___SQLCompiledPath = SQLCompiledPath

@typing.final
class SQLCompiledPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SQLCompiledPath: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SQLCompiledPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SQLCompiledPathMsg = SQLCompiledPathMsg

@typing.final
class CheckNodeTestFailure(google.protobuf.message.Message):
    """Z027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_NAME_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    relation_name: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        relation_name: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "relation_name", b"relation_name"]) -> None: ...

global___CheckNodeTestFailure = CheckNodeTestFailure

@typing.final
class CheckNodeTestFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___CheckNodeTestFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___CheckNodeTestFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___CheckNodeTestFailureMsg = CheckNodeTestFailureMsg

@typing.final
class EndOfRunSummary(google.protobuf.message.Message):
    """Skipped Z028, Z029

    Z030
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_ERRORS_FIELD_NUMBER: builtins.int
    NUM_WARNINGS_FIELD_NUMBER: builtins.int
    KEYBOARD_INTERRUPT_FIELD_NUMBER: builtins.int
    NUM_PARTIAL_SUCCESS_FIELD_NUMBER: builtins.int
    num_errors: builtins.int
    num_warnings: builtins.int
    keyboard_interrupt: builtins.bool
    num_partial_success: builtins.int
    def __init__(
        self,
        *,
        num_errors: builtins.int = ...,
        num_warnings: builtins.int = ...,
        keyboard_interrupt: builtins.bool = ...,
        num_partial_success: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keyboard_interrupt", b"keyboard_interrupt", "num_errors", b"num_errors", "num_partial_success", b"num_partial_success", "num_warnings", b"num_warnings"]) -> None: ...

global___EndOfRunSummary = EndOfRunSummary

@typing.final
class EndOfRunSummaryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___EndOfRunSummary: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___EndOfRunSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___EndOfRunSummaryMsg = EndOfRunSummaryMsg

@typing.final
class MarkSkippedChildren(google.protobuf.message.Message):
    """Skipped Z031, Z032

    Z033
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RUN_RESULT_FIELD_NUMBER: builtins.int
    unique_id: builtins.str
    status: builtins.str
    @property
    def run_result(self) -> global___RunResultMsg: ...
    def __init__(
        self,
        *,
        unique_id: builtins.str = ...,
        status: builtins.str = ...,
        run_result: global___RunResultMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["run_result", b"run_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["run_result", b"run_result", "status", b"status", "unique_id", b"unique_id"]) -> None: ...

global___MarkSkippedChildren = MarkSkippedChildren

@typing.final
class MarkSkippedChildrenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___MarkSkippedChildren: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___MarkSkippedChildren | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___MarkSkippedChildrenMsg = MarkSkippedChildrenMsg

@typing.final
class LogSkipBecauseError(google.protobuf.message.Message):
    """Z034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    schema: builtins.str
    relation: builtins.str
    index: builtins.int
    total: builtins.int
    status: builtins.str
    @property
    def group(self) -> global___Group: ...
    def __init__(
        self,
        *,
        schema: builtins.str = ...,
        relation: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        status: builtins.str = ...,
        group: global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "index", b"index", "relation", b"relation", "schema", b"schema", "status", b"status", "total", b"total"]) -> None: ...

global___LogSkipBecauseError = LogSkipBecauseError

@typing.final
class LogSkipBecauseErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___LogSkipBecauseError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___LogSkipBecauseError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___LogSkipBecauseErrorMsg = LogSkipBecauseErrorMsg

@typing.final
class EnsureGitInstalled(google.protobuf.message.Message):
    """Z036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EnsureGitInstalled = EnsureGitInstalled

@typing.final
class EnsureGitInstalledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___EnsureGitInstalled: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___EnsureGitInstalled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___EnsureGitInstalledMsg = EnsureGitInstalledMsg

@typing.final
class DepsCreatingLocalSymlink(google.protobuf.message.Message):
    """Z037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DepsCreatingLocalSymlink = DepsCreatingLocalSymlink

@typing.final
class DepsCreatingLocalSymlinkMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsCreatingLocalSymlink: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsCreatingLocalSymlink | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsCreatingLocalSymlinkMsg = DepsCreatingLocalSymlinkMsg

@typing.final
class DepsSymlinkNotAvailable(google.protobuf.message.Message):
    """Z038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DepsSymlinkNotAvailable = DepsSymlinkNotAvailable

@typing.final
class DepsSymlinkNotAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DepsSymlinkNotAvailable: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DepsSymlinkNotAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DepsSymlinkNotAvailableMsg = DepsSymlinkNotAvailableMsg

@typing.final
class DisableTracking(google.protobuf.message.Message):
    """Z039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DisableTracking = DisableTracking

@typing.final
class DisableTrackingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DisableTracking: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DisableTracking | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DisableTrackingMsg = DisableTrackingMsg

@typing.final
class SendingEvent(google.protobuf.message.Message):
    """Z040"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KWARGS_FIELD_NUMBER: builtins.int
    kwargs: builtins.str
    def __init__(
        self,
        *,
        kwargs: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["kwargs", b"kwargs"]) -> None: ...

global___SendingEvent = SendingEvent

@typing.final
class SendingEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SendingEvent: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SendingEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SendingEventMsg = SendingEventMsg

@typing.final
class SendEventFailure(google.protobuf.message.Message):
    """Z041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendEventFailure = SendEventFailure

@typing.final
class SendEventFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___SendEventFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___SendEventFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___SendEventFailureMsg = SendEventFailureMsg

@typing.final
class FlushEvents(google.protobuf.message.Message):
    """Z042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FlushEvents = FlushEvents

@typing.final
class FlushEventsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FlushEvents: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FlushEvents | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FlushEventsMsg = FlushEventsMsg

@typing.final
class FlushEventsFailure(google.protobuf.message.Message):
    """Z043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FlushEventsFailure = FlushEventsFailure

@typing.final
class FlushEventsFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___FlushEventsFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___FlushEventsFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___FlushEventsFailureMsg = FlushEventsFailureMsg

@typing.final
class TrackingInitializeFailure(google.protobuf.message.Message):
    """Z044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

global___TrackingInitializeFailure = TrackingInitializeFailure

@typing.final
class TrackingInitializeFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___TrackingInitializeFailure: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___TrackingInitializeFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___TrackingInitializeFailureMsg = TrackingInitializeFailureMsg

@typing.final
class RunResultWarningMessage(google.protobuf.message.Message):
    """Skipped Z045

    Z046
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> global___NodeInfo: ...
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        node_info: global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

global___RunResultWarningMessage = RunResultWarningMessage

@typing.final
class RunResultWarningMessageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___RunResultWarningMessage: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___RunResultWarningMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___RunResultWarningMessageMsg = RunResultWarningMessageMsg

@typing.final
class DebugCmdOut(google.protobuf.message.Message):
    """Z047"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___DebugCmdOut = DebugCmdOut

@typing.final
class DebugCmdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DebugCmdOut: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DebugCmdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DebugCmdOutMsg = DebugCmdOutMsg

@typing.final
class DebugCmdResult(google.protobuf.message.Message):
    """Z048"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___DebugCmdResult = DebugCmdResult

@typing.final
class DebugCmdResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___DebugCmdResult: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___DebugCmdResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___DebugCmdResultMsg = DebugCmdResultMsg

@typing.final
class ListCmdOut(google.protobuf.message.Message):
    """Z049"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___ListCmdOut = ListCmdOut

@typing.final
class ListCmdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ListCmdOut: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ListCmdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ListCmdOutMsg = ListCmdOutMsg

@typing.final
class ResourceReport(google.protobuf.message.Message):
    """Z051"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_NAME_FIELD_NUMBER: builtins.int
    COMMAND_SUCCESS_FIELD_NUMBER: builtins.int
    COMMAND_WALL_CLOCK_TIME_FIELD_NUMBER: builtins.int
    PROCESS_USER_TIME_FIELD_NUMBER: builtins.int
    PROCESS_KERNEL_TIME_FIELD_NUMBER: builtins.int
    PROCESS_MEM_MAX_RSS_FIELD_NUMBER: builtins.int
    PROCESS_IN_BLOCKS_FIELD_NUMBER: builtins.int
    PROCESS_OUT_BLOCKS_FIELD_NUMBER: builtins.int
    command_name: builtins.str
    command_success: builtins.bool
    command_wall_clock_time: builtins.float
    process_user_time: builtins.float
    """The process_* metrics reflect the resource consumption of the process as
    a whole when the command completes. When dbt is being used as a library,
    these will reflect the resource consumption of the host process as a whole,
    rather than the resources used exclusively by the command.
    """
    process_kernel_time: builtins.float
    process_mem_max_rss: builtins.int
    process_in_blocks: builtins.int
    process_out_blocks: builtins.int
    def __init__(
        self,
        *,
        command_name: builtins.str = ...,
        command_success: builtins.bool = ...,
        command_wall_clock_time: builtins.float = ...,
        process_user_time: builtins.float = ...,
        process_kernel_time: builtins.float = ...,
        process_mem_max_rss: builtins.int = ...,
        process_in_blocks: builtins.int = ...,
        process_out_blocks: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["command_name", b"command_name", "command_success", b"command_success", "command_wall_clock_time", b"command_wall_clock_time", "process_in_blocks", b"process_in_blocks", "process_kernel_time", b"process_kernel_time", "process_mem_max_rss", b"process_mem_max_rss", "process_out_blocks", b"process_out_blocks", "process_user_time", b"process_user_time"]) -> None: ...

global___ResourceReport = ResourceReport

@typing.final
class ResourceReportMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ResourceReport: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ResourceReport | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ResourceReportMsg = ResourceReportMsg

@typing.final
class ObservabilityMetric(google.protobuf.message.Message):
    """Z052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DEBUG_MESSAGE_FIELD_NUMBER: builtins.int
    label: builtins.str
    value: builtins.float
    debug_message: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        value: builtins.float = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        debug_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["debug_message", b"debug_message", "label", b"label", "tags", b"tags", "value", b"value"]) -> None: ...

global___ObservabilityMetric = ObservabilityMetric

@typing.final
class ObservabilityMetricMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ObservabilityMetric: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ObservabilityMetric | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ObservabilityMetricMsg = ObservabilityMetricMsg

@typing.final
class ArtifactUploadError(google.protobuf.message.Message):
    """Z061"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___ArtifactUploadError = ArtifactUploadError

@typing.final
class ArtifactUploadErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ArtifactUploadError: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ArtifactUploadError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ArtifactUploadErrorMsg = ArtifactUploadErrorMsg

@typing.final
class ArtifactUploadSuccess(google.protobuf.message.Message):
    """Z062"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___ArtifactUploadSuccess = ArtifactUploadSuccess

@typing.final
class ArtifactUploadSuccessMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ArtifactUploadSuccess: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ArtifactUploadSuccess | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ArtifactUploadSuccessMsg = ArtifactUploadSuccessMsg

@typing.final
class ArtifactUploadSkipped(google.protobuf.message.Message):
    """Z063"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

global___ArtifactUploadSkipped = ArtifactUploadSkipped

@typing.final
class ArtifactUploadSkippedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___CoreEventInfo: ...
    @property
    def data(self) -> global___ArtifactUploadSkipped: ...
    def __init__(
        self,
        *,
        info: global___CoreEventInfo | None = ...,
        data: global___ArtifactUploadSkipped | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

global___ArtifactUploadSkippedMsg = ArtifactUploadSkippedMsg
